
from typing import Union
from .services.as2_connector_record import As2ConnectorRecordService
from .services.account import AccountService
from .services.account_cloud_attachment_properties import (
    AccountCloudAttachmentPropertiesService,
)
from .services.account_cloud_attachment_quota import AccountCloudAttachmentQuotaService
from .services.account_group import AccountGroupService
from .services.account_group_account import AccountGroupAccountService
from .services.account_group_user_role import AccountGroupUserRoleService
from .services.account_sso_config import AccountSsoConfigService
from .services.account_user_federation import AccountUserFederationService
from .services.account_user_role import AccountUserRoleService
from .services.api_usage_count import ApiUsageCountService
from .services.atom import AtomService
from .services.atom_as2_artifacts import AtomAs2ArtifactsService
from .services.atom_connection_field_extension_summary import (
    AtomConnectionFieldExtensionSummaryService,
)
from .services.atom_connector_versions import AtomConnectorVersionsService
from .services.atom_counters import AtomCountersService
from .services.atom_log import AtomLogService
from .services.atom_purge import AtomPurgeService
from .services.atom_security_policies import AtomSecurityPoliciesService
from .services.atom_startup_properties import AtomStartupPropertiesService
from .services.atom_worker_log import AtomWorkerLogService
from .services.audit_log import AuditLogService
from .services.branch import BranchService
from .services.change_listener_status import ChangeListenerStatusService
from .services.clear_queue import ClearQueueService
from .services.cloud import CloudService
from .services.cloud_attachment_properties import CloudAttachmentPropertiesService
from .services.component import ComponentService
from .services.component_atom_attachment import ComponentAtomAttachmentService
from .services.component_diff_request import ComponentDiffRequestService
from .services.component_environment_attachment import (
    ComponentEnvironmentAttachmentService,
)
from .services.component_metadata import ComponentMetadataService
from .services.component_reference import ComponentReferenceService
from .services.connection_licensing_report import ConnectionLicensingReportService
from .services.connector import ConnectorService
from .services.connector_document import ConnectorDocumentService
from .services.custom_tracked_field import CustomTrackedFieldService
from .services.deployed_expired_certificate import DeployedExpiredCertificateService
from .services.deployed_package import DeployedPackageService
from .services.deployment import DeploymentService
from .services.document_count_account import DocumentCountAccountService
from .services.document_count_account_group import DocumentCountAccountGroupService
from .services.edifact_connector_record import EdifactConnectorRecordService
from .services.edi_custom_connector_record import EdiCustomConnectorRecordService
from .services.environment import EnvironmentService
from .services.environment_atom_attachment import EnvironmentAtomAttachmentService
from .services.environment_connection_field_extension_summary import (
    EnvironmentConnectionFieldExtensionSummaryService,
)
from .services.environment_extensions import EnvironmentExtensionsService
from .services.environment_map_extension import EnvironmentMapExtensionService
from .services.environment_map_extension_external_component import (
    EnvironmentMapExtensionExternalComponentService,
)
from .services.environment_map_extension_user_defined_function import (
    EnvironmentMapExtensionUserDefinedFunctionService,
)
from .services.environment_map_extension_user_defined_function_summary import (
    EnvironmentMapExtensionUserDefinedFunctionSummaryService,
)
from .services.environment_map_extensions_summary import (
    EnvironmentMapExtensionsSummaryService,
)
from .services.environment_role import EnvironmentRoleService
from .services.event import EventService
from .services.execution_artifacts import ExecutionArtifactsService
from .services.execution_connector import ExecutionConnectorService
from .services.execution_count_account import ExecutionCountAccountService
from .services.execution_count_account_group import ExecutionCountAccountGroupService
from .services.execution_record import ExecutionRecordService
from .services.execution_request import ExecutionRequestService
from .services.execution_summary_record import ExecutionSummaryRecordService
from .services.folder import FolderService
from .services.generic_connector_record import GenericConnectorRecordService
from .services.get_assignable_roles import GetAssignableRolesService
from .services.hl7_connector_record import Hl7ConnectorRecordService
from .services.installer_token import InstallerTokenService
from .services.integration_pack import IntegrationPackService
from .services.integration_pack_atom_attachment import (
    IntegrationPackAtomAttachmentService,
)
from .services.integration_pack_environment_attachment import (
    IntegrationPackEnvironmentAttachmentService,
)
from .services.integration_pack_instance import IntegrationPackInstanceService
from .services.java_rollback import JavaRollbackService
from .services.java_upgrade import JavaUpgradeService
from .services.merge_request import MergeRequestService
from .services.move_queue_request import MoveQueueRequestService
from .services.node_offboard import NodeOffboardService
from .services.odette_connector_record import OdetteConnectorRecordService
from .services.oftp2_connector_record import Oftp2ConnectorRecordService
from .services.packaged_component import PackagedComponentService
from .services.packaged_component_manifest import PackagedComponentManifestService
from .services.persisted_process_properties import PersistedProcessPropertiesService
from .services.process import ProcessService
from .services.process_atom_attachment import ProcessAtomAttachmentService
from .services.process_environment_attachment import ProcessEnvironmentAttachmentService
from .services.process_log import ProcessLogService
from .services.process_schedule_status import ProcessScheduleStatusService
from .services.process_schedules import ProcessSchedulesService
from .services.rerun_document import RerunDocumentService
from .services.role import RoleService
from .services.rosetta_net_connector_record import RosettaNetConnectorRecordService
from .services.runtime_release_schedule import RuntimeReleaseScheduleService
from .services.cancel_execution import CancelExecutionService
from .services.shared_server_information import SharedServerInformationService
from .services.shared_web_server import SharedWebServerService
from .services.throughput_account import ThroughputAccountService
from .services.throughput_account_group import ThroughputAccountGroupService
from .services.tradacoms_connector_record import TradacomsConnectorRecordService
from .services.trading_partner_component import TradingPartnerComponentService
from .services.trading_partner_processing_group import (
    TradingPartnerProcessingGroupService,
)
from .services.x12_connector_record import X12ConnectorRecordService
from .services.atom_disk_space import AtomDiskSpaceService
from .services.list_queues import ListQueuesService
from .services.listener_status import ListenerStatusService
from .services.organization_component import OrganizationComponentService
from .services.shared_communication_channel_component import (
    SharedCommunicationChannelComponentService,
)
from .services.account_group_integration_pack import AccountGroupIntegrationPackService
from .services.publisher_integration_pack import PublisherIntegrationPackService
from .services.release_integration_pack import ReleaseIntegrationPackService
from .services.release_integration_pack_status import (
    ReleaseIntegrationPackStatusService,
)
from .services.runtime_restart_request import RuntimeRestartRequestService
from .services.refresh_secrets_manager import RefreshSecretsManagerService
from .services.runtime_cloud import RuntimeCloudService
from .services.account_cloud_attachment_summary import (
    AccountCloudAttachmentSummaryService,
)
from .services.account_cloud_attachment_properties_default import (
    AccountCloudAttachmentPropertiesDefaultService,
)
from .services.runtime_properties import RuntimePropertiesService
from .services.runtime_observability_settings import (
    RuntimeObservabilitySettingsService,
)
from .services.cloud_attachment_secrets_configuration import (
    CloudAttachmentSecretsConfigurationService,
)
from .net.environment import Environment


class Boomi:
    def __init__(
        self,
        access_token: str = None,
        username: str = None,
        password: str = None,
        base_url: Union[Environment, str, None] = None,
        timeout: int = 60000,
        account_id: str = "platform_account_ID",
    ):
        """
        Initializes Boomi the SDK class.
        """

        self._base_url = (
            base_url.value if isinstance(base_url, Environment) else base_url
        )
        self.as2_connector_record = As2ConnectorRecordService(base_url=self._base_url)
        self.account = AccountService(base_url=self._base_url)
        self.account_cloud_attachment_properties = (
            AccountCloudAttachmentPropertiesService(base_url=self._base_url)
        )
        self.account_cloud_attachment_quota = AccountCloudAttachmentQuotaService(
            base_url=self._base_url
        )
        self.account_group = AccountGroupService(base_url=self._base_url)
        self.account_group_account = AccountGroupAccountService(base_url=self._base_url)
        self.account_group_user_role = AccountGroupUserRoleService(
            base_url=self._base_url
        )
        self.account_sso_config = AccountSsoConfigService(base_url=self._base_url)
        self.account_user_federation = AccountUserFederationService(
            base_url=self._base_url
        )
        self.account_user_role = AccountUserRoleService(base_url=self._base_url)
        self.api_usage_count = ApiUsageCountService(base_url=self._base_url)
        self.atom = AtomService(base_url=self._base_url)
        self.atom_as2_artifacts = AtomAs2ArtifactsService(base_url=self._base_url)
        self.atom_connection_field_extension_summary = (
            AtomConnectionFieldExtensionSummaryService(base_url=self._base_url)
        )
        self.atom_connector_versions = AtomConnectorVersionsService(
            base_url=self._base_url
        )
        self.atom_counters = AtomCountersService(base_url=self._base_url)
        self.atom_log = AtomLogService(base_url=self._base_url)
        self.atom_purge = AtomPurgeService(base_url=self._base_url)
        self.atom_security_policies = AtomSecurityPoliciesService(
            base_url=self._base_url
        )
        self.atom_startup_properties = AtomStartupPropertiesService(
            base_url=self._base_url
        )
        self.atom_worker_log = AtomWorkerLogService(base_url=self._base_url)
        self.audit_log = AuditLogService(base_url=self._base_url)
        self.branch = BranchService(base_url=self._base_url)
        self.change_listener_status = ChangeListenerStatusService(
            base_url=self._base_url
        )
        self.clear_queue = ClearQueueService(base_url=self._base_url)
        self.cloud = CloudService(base_url=self._base_url)
        self.cloud_attachment_properties = CloudAttachmentPropertiesService(
            base_url=self._base_url
        )
        self.component = ComponentService(base_url=self._base_url)
        self.component_atom_attachment = ComponentAtomAttachmentService(
            base_url=self._base_url
        )
        self.component_diff_request = ComponentDiffRequestService(
            base_url=self._base_url
        )
        self.component_environment_attachment = ComponentEnvironmentAttachmentService(
            base_url=self._base_url
        )
        self.component_metadata = ComponentMetadataService(base_url=self._base_url)
        self.component_reference = ComponentReferenceService(base_url=self._base_url)
        self.connection_licensing_report = ConnectionLicensingReportService(
            base_url=self._base_url
        )
        self.connector = ConnectorService(base_url=self._base_url)
        self.connector_document = ConnectorDocumentService(base_url=self._base_url)
        self.custom_tracked_field = CustomTrackedFieldService(base_url=self._base_url)
        self.deployed_expired_certificate = DeployedExpiredCertificateService(
            base_url=self._base_url
        )
        self.deployed_package = DeployedPackageService(base_url=self._base_url)
        self.deployment = DeploymentService(base_url=self._base_url)
        self.document_count_account = DocumentCountAccountService(
            base_url=self._base_url
        )
        self.document_count_account_group = DocumentCountAccountGroupService(
            base_url=self._base_url
        )
        self.edifact_connector_record = EdifactConnectorRecordService(
            base_url=self._base_url
        )
        self.edi_custom_connector_record = EdiCustomConnectorRecordService(
            base_url=self._base_url
        )
        self.environment = EnvironmentService(base_url=self._base_url)
        self.environment_atom_attachment = EnvironmentAtomAttachmentService(
            base_url=self._base_url
        )
        self.environment_connection_field_extension_summary = (
            EnvironmentConnectionFieldExtensionSummaryService(base_url=self._base_url)
        )
        self.environment_extensions = EnvironmentExtensionsService(
            base_url=self._base_url
        )
        self.environment_map_extension = EnvironmentMapExtensionService(
            base_url=self._base_url
        )
        self.environment_map_extension_external_component = (
            EnvironmentMapExtensionExternalComponentService(base_url=self._base_url)
        )
        self.environment_map_extension_user_defined_function = (
            EnvironmentMapExtensionUserDefinedFunctionService(base_url=self._base_url)
        )
        self.environment_map_extension_user_defined_function_summary = (
            EnvironmentMapExtensionUserDefinedFunctionSummaryService(
                base_url=self._base_url
            )
        )
        self.environment_map_extensions_summary = (
            EnvironmentMapExtensionsSummaryService(base_url=self._base_url)
        )
        self.environment_role = EnvironmentRoleService(base_url=self._base_url)
        self.event = EventService(base_url=self._base_url)
        self.execution_artifacts = ExecutionArtifactsService(base_url=self._base_url)
        self.execution_connector = ExecutionConnectorService(base_url=self._base_url)
        self.execution_count_account = ExecutionCountAccountService(
            base_url=self._base_url
        )
        self.execution_count_account_group = ExecutionCountAccountGroupService(
            base_url=self._base_url
        )
        self.execution_record = ExecutionRecordService(base_url=self._base_url)
        self.execution_request = ExecutionRequestService(base_url=self._base_url)
        self.execution_summary_record = ExecutionSummaryRecordService(
            base_url=self._base_url
        )
        self.folder = FolderService(base_url=self._base_url)
        self.generic_connector_record = GenericConnectorRecordService(
            base_url=self._base_url
        )
        self.get_assignable_roles = GetAssignableRolesService(base_url=self._base_url)
        self.hl7_connector_record = Hl7ConnectorRecordService(base_url=self._base_url)
        self.installer_token = InstallerTokenService(base_url=self._base_url)
        self.integration_pack = IntegrationPackService(base_url=self._base_url)
        self.integration_pack_atom_attachment = IntegrationPackAtomAttachmentService(
            base_url=self._base_url
        )
        self.integration_pack_environment_attachment = (
            IntegrationPackEnvironmentAttachmentService(base_url=self._base_url)
        )
        self.integration_pack_instance = IntegrationPackInstanceService(
            base_url=self._base_url
        )
        self.java_rollback = JavaRollbackService(base_url=self._base_url)
        self.java_upgrade = JavaUpgradeService(base_url=self._base_url)
        self.merge_request = MergeRequestService(base_url=self._base_url)
        self.move_queue_request = MoveQueueRequestService(base_url=self._base_url)
        self.node_offboard = NodeOffboardService(base_url=self._base_url)
        self.odette_connector_record = OdetteConnectorRecordService(
            base_url=self._base_url
        )
        self.oftp2_connector_record = Oftp2ConnectorRecordService(
            base_url=self._base_url
        )
        self.packaged_component = PackagedComponentService(base_url=self._base_url)
        self.packaged_component_manifest = PackagedComponentManifestService(
            base_url=self._base_url
        )
        self.persisted_process_properties = PersistedProcessPropertiesService(
            base_url=self._base_url
        )
        self.process = ProcessService(base_url=self._base_url)
        self.process_atom_attachment = ProcessAtomAttachmentService(
            base_url=self._base_url
        )
        self.process_environment_attachment = ProcessEnvironmentAttachmentService(
            base_url=self._base_url
        )
        self.process_log = ProcessLogService(base_url=self._base_url)
        self.process_schedule_status = ProcessScheduleStatusService(
            base_url=self._base_url
        )
        self.process_schedules = ProcessSchedulesService(base_url=self._base_url)
        self.rerun_document = RerunDocumentService(base_url=self._base_url)
        self.role = RoleService(base_url=self._base_url)
        self.rosetta_net_connector_record = RosettaNetConnectorRecordService(
            base_url=self._base_url
        )
        self.runtime_release_schedule = RuntimeReleaseScheduleService(
            base_url=self._base_url
        )
        self.cancel_execution = CancelExecutionService(base_url=self._base_url)
        self.shared_server_information = SharedServerInformationService(
            base_url=self._base_url
        )
        self.shared_web_server = SharedWebServerService(base_url=self._base_url)
        self.throughput_account = ThroughputAccountService(base_url=self._base_url)
        self.throughput_account_group = ThroughputAccountGroupService(
            base_url=self._base_url
        )
        self.tradacoms_connector_record = TradacomsConnectorRecordService(
            base_url=self._base_url
        )
        self.trading_partner_component = TradingPartnerComponentService(
            base_url=self._base_url
        )
        self.trading_partner_processing_group = TradingPartnerProcessingGroupService(
            base_url=self._base_url
        )
        self.x12_connector_record = X12ConnectorRecordService(base_url=self._base_url)
        self.atom_disk_space = AtomDiskSpaceService(base_url=self._base_url)
        self.list_queues = ListQueuesService(base_url=self._base_url)
        self.listener_status = ListenerStatusService(base_url=self._base_url)
        self.organization_component = OrganizationComponentService(
            base_url=self._base_url
        )
        self.shared_communication_channel_component = (
            SharedCommunicationChannelComponentService(base_url=self._base_url)
        )
        self.account_group_integration_pack = AccountGroupIntegrationPackService(
            base_url=self._base_url
        )
        self.publisher_integration_pack = PublisherIntegrationPackService(
            base_url=self._base_url
        )
        self.release_integration_pack = ReleaseIntegrationPackService(
            base_url=self._base_url
        )
        self.release_integration_pack_status = ReleaseIntegrationPackStatusService(
            base_url=self._base_url
        )
        self.runtime_restart_request = RuntimeRestartRequestService(
            base_url=self._base_url
        )
        self.refresh_secrets_manager = RefreshSecretsManagerService(
            base_url=self._base_url
        )
        self.runtime_cloud = RuntimeCloudService(base_url=self._base_url)
        self.account_cloud_attachment_summary = (
            AccountCloudAttachmentSummaryService(base_url=self._base_url)
        )
        self.account_cloud_attachment_properties_default = (
            AccountCloudAttachmentPropertiesDefaultService(base_url=self._base_url)
        )
        self.runtime_properties = RuntimePropertiesService(base_url=self._base_url)
        self.runtime_observability_settings = RuntimeObservabilitySettingsService(
            base_url=self._base_url
        )
        self.cloud_attachment_secrets_configuration = (
            CloudAttachmentSecretsConfigurationService(base_url=self._base_url)
        )
        self.set_access_token(access_token)
        self.set_basic_auth(username=username, password=password)
        self._base_url_account_id = account_id
        self.set_base_url(self._base_url)
        self.set_timeout(timeout)

    def set_base_url(self, base_url: Union[Environment, str]):
        """
        Sets the base URL for the entire SDK.

        :param Union[Environment, str] base_url: The base URL to be set.
        :return: The SDK instance.
        """
        self._base_url = (
            base_url.value if isinstance(base_url, Environment) else base_url
        )
        formatted_url = (self._base_url or Environment.DEFAULT.url).format(
            accountId=self._base_url_account_id
        )

        self.as2_connector_record.set_base_url(formatted_url)
        self.account.set_base_url(formatted_url)
        self.account_cloud_attachment_properties.set_base_url(formatted_url)
        self.account_cloud_attachment_quota.set_base_url(formatted_url)
        self.account_group.set_base_url(formatted_url)
        self.account_group_account.set_base_url(formatted_url)
        self.account_group_user_role.set_base_url(formatted_url)
        self.account_sso_config.set_base_url(formatted_url)
        self.account_user_federation.set_base_url(formatted_url)
        self.account_user_role.set_base_url(formatted_url)
        self.api_usage_count.set_base_url(formatted_url)
        self.atom.set_base_url(formatted_url)
        self.atom_as2_artifacts.set_base_url(formatted_url)
        self.atom_connection_field_extension_summary.set_base_url(formatted_url)
        self.atom_connector_versions.set_base_url(formatted_url)
        self.atom_counters.set_base_url(formatted_url)
        self.atom_log.set_base_url(formatted_url)
        self.atom_purge.set_base_url(formatted_url)
        self.atom_security_policies.set_base_url(formatted_url)
        self.atom_startup_properties.set_base_url(formatted_url)
        self.atom_worker_log.set_base_url(formatted_url)
        self.audit_log.set_base_url(formatted_url)
        self.branch.set_base_url(formatted_url)
        self.change_listener_status.set_base_url(formatted_url)
        self.clear_queue.set_base_url(formatted_url)
        self.cloud.set_base_url(formatted_url)
        self.cloud_attachment_properties.set_base_url(formatted_url)
        self.component.set_base_url(formatted_url)
        self.component_atom_attachment.set_base_url(formatted_url)
        self.component_diff_request.set_base_url(formatted_url)
        self.component_environment_attachment.set_base_url(formatted_url)
        self.component_metadata.set_base_url(formatted_url)
        self.component_reference.set_base_url(formatted_url)
        self.connection_licensing_report.set_base_url(formatted_url)
        self.connector.set_base_url(formatted_url)
        self.connector_document.set_base_url(formatted_url)
        self.custom_tracked_field.set_base_url(formatted_url)
        self.deployed_expired_certificate.set_base_url(formatted_url)
        self.deployed_package.set_base_url(formatted_url)
        self.deployment.set_base_url(formatted_url)
        self.document_count_account.set_base_url(formatted_url)
        self.document_count_account_group.set_base_url(formatted_url)
        self.edifact_connector_record.set_base_url(formatted_url)
        self.edi_custom_connector_record.set_base_url(formatted_url)
        self.environment.set_base_url(formatted_url)
        self.environment_atom_attachment.set_base_url(formatted_url)
        self.environment_connection_field_extension_summary.set_base_url(formatted_url)
        self.environment_extensions.set_base_url(formatted_url)
        self.environment_map_extension.set_base_url(formatted_url)
        self.environment_map_extension_external_component.set_base_url(formatted_url)
        self.environment_map_extension_user_defined_function.set_base_url(formatted_url)
        self.environment_map_extension_user_defined_function_summary.set_base_url(
            formatted_url
        )
        self.environment_map_extensions_summary.set_base_url(formatted_url)
        self.environment_role.set_base_url(formatted_url)
        self.event.set_base_url(formatted_url)
        self.execution_artifacts.set_base_url(formatted_url)
        self.execution_connector.set_base_url(formatted_url)
        self.execution_count_account.set_base_url(formatted_url)
        self.execution_count_account_group.set_base_url(formatted_url)
        self.execution_record.set_base_url(formatted_url)
        self.execution_request.set_base_url(formatted_url)
        self.execution_summary_record.set_base_url(formatted_url)
        self.folder.set_base_url(formatted_url)
        self.generic_connector_record.set_base_url(formatted_url)
        self.get_assignable_roles.set_base_url(formatted_url)
        self.hl7_connector_record.set_base_url(formatted_url)
        self.installer_token.set_base_url(formatted_url)
        self.integration_pack.set_base_url(formatted_url)
        self.integration_pack_atom_attachment.set_base_url(formatted_url)
        self.integration_pack_environment_attachment.set_base_url(formatted_url)
        self.integration_pack_instance.set_base_url(formatted_url)
        self.java_rollback.set_base_url(formatted_url)
        self.java_upgrade.set_base_url(formatted_url)
        self.merge_request.set_base_url(formatted_url)
        self.move_queue_request.set_base_url(formatted_url)
        self.node_offboard.set_base_url(formatted_url)
        self.odette_connector_record.set_base_url(formatted_url)
        self.oftp2_connector_record.set_base_url(formatted_url)
        self.packaged_component.set_base_url(formatted_url)
        self.packaged_component_manifest.set_base_url(formatted_url)
        self.persisted_process_properties.set_base_url(formatted_url)
        self.process.set_base_url(formatted_url)
        self.process_atom_attachment.set_base_url(formatted_url)
        self.process_environment_attachment.set_base_url(formatted_url)
        self.process_log.set_base_url(formatted_url)
        self.process_schedule_status.set_base_url(formatted_url)
        self.process_schedules.set_base_url(formatted_url)
        self.rerun_document.set_base_url(formatted_url)
        self.role.set_base_url(formatted_url)
        self.rosetta_net_connector_record.set_base_url(formatted_url)
        self.runtime_release_schedule.set_base_url(formatted_url)
        self.cancel_execution.set_base_url(formatted_url)
        self.shared_server_information.set_base_url(formatted_url)
        self.shared_web_server.set_base_url(formatted_url)
        self.throughput_account.set_base_url(formatted_url)
        self.throughput_account_group.set_base_url(formatted_url)
        self.tradacoms_connector_record.set_base_url(formatted_url)
        self.trading_partner_component.set_base_url(formatted_url)
        self.trading_partner_processing_group.set_base_url(formatted_url)
        self.x12_connector_record.set_base_url(formatted_url)
        self.atom_disk_space.set_base_url(formatted_url)
        self.list_queues.set_base_url(formatted_url)
        self.listener_status.set_base_url(formatted_url)
        self.organization_component.set_base_url(formatted_url)
        self.shared_communication_channel_component.set_base_url(formatted_url)
        self.account_group_integration_pack.set_base_url(formatted_url)
        self.publisher_integration_pack.set_base_url(formatted_url)
        self.release_integration_pack.set_base_url(formatted_url)
        self.release_integration_pack_status.set_base_url(formatted_url)
        self.runtime_restart_request.set_base_url(formatted_url)
        self.refresh_secrets_manager.set_base_url(formatted_url)
        self.runtime_cloud.set_base_url(formatted_url)
        self.account_cloud_attachment_summary.set_base_url(formatted_url)
        self.account_cloud_attachment_properties_default.set_base_url(formatted_url)
        self.runtime_properties.set_base_url(formatted_url)
        self.runtime_observability_settings.set_base_url(formatted_url)
        self.cloud_attachment_secrets_configuration.set_base_url(formatted_url)

        return self

    def set_access_token(self, access_token: str):
        """
        Sets the access token for the entire SDK.
        """
        self.as2_connector_record.set_access_token(access_token)
        self.account.set_access_token(access_token)
        self.account_cloud_attachment_properties.set_access_token(access_token)
        self.account_cloud_attachment_quota.set_access_token(access_token)
        self.account_group.set_access_token(access_token)
        self.account_group_account.set_access_token(access_token)
        self.account_group_user_role.set_access_token(access_token)
        self.account_sso_config.set_access_token(access_token)
        self.account_user_federation.set_access_token(access_token)
        self.account_user_role.set_access_token(access_token)
        self.api_usage_count.set_access_token(access_token)
        self.atom.set_access_token(access_token)
        self.atom_as2_artifacts.set_access_token(access_token)
        self.atom_connection_field_extension_summary.set_access_token(access_token)
        self.atom_connector_versions.set_access_token(access_token)
        self.atom_counters.set_access_token(access_token)
        self.atom_log.set_access_token(access_token)
        self.atom_purge.set_access_token(access_token)
        self.atom_security_policies.set_access_token(access_token)
        self.atom_startup_properties.set_access_token(access_token)
        self.atom_worker_log.set_access_token(access_token)
        self.audit_log.set_access_token(access_token)
        self.branch.set_access_token(access_token)
        self.change_listener_status.set_access_token(access_token)
        self.clear_queue.set_access_token(access_token)
        self.cloud.set_access_token(access_token)
        self.cloud_attachment_properties.set_access_token(access_token)
        self.component.set_access_token(access_token)
        self.component_atom_attachment.set_access_token(access_token)
        self.component_diff_request.set_access_token(access_token)
        self.component_environment_attachment.set_access_token(access_token)
        self.component_metadata.set_access_token(access_token)
        self.component_reference.set_access_token(access_token)
        self.connection_licensing_report.set_access_token(access_token)
        self.connector.set_access_token(access_token)
        self.connector_document.set_access_token(access_token)
        self.custom_tracked_field.set_access_token(access_token)
        self.deployed_expired_certificate.set_access_token(access_token)
        self.deployed_package.set_access_token(access_token)
        self.deployment.set_access_token(access_token)
        self.document_count_account.set_access_token(access_token)
        self.document_count_account_group.set_access_token(access_token)
        self.edifact_connector_record.set_access_token(access_token)
        self.edi_custom_connector_record.set_access_token(access_token)
        self.environment.set_access_token(access_token)
        self.environment_atom_attachment.set_access_token(access_token)
        self.environment_connection_field_extension_summary.set_access_token(
            access_token
        )
        self.environment_extensions.set_access_token(access_token)
        self.environment_map_extension.set_access_token(access_token)
        self.environment_map_extension_external_component.set_access_token(access_token)
        self.environment_map_extension_user_defined_function.set_access_token(
            access_token
        )
        self.environment_map_extension_user_defined_function_summary.set_access_token(
            access_token
        )
        self.environment_map_extensions_summary.set_access_token(access_token)
        self.environment_role.set_access_token(access_token)
        self.event.set_access_token(access_token)
        self.execution_artifacts.set_access_token(access_token)
        self.execution_connector.set_access_token(access_token)
        self.execution_count_account.set_access_token(access_token)
        self.execution_count_account_group.set_access_token(access_token)
        self.execution_record.set_access_token(access_token)
        self.execution_request.set_access_token(access_token)
        self.execution_summary_record.set_access_token(access_token)
        self.folder.set_access_token(access_token)
        self.generic_connector_record.set_access_token(access_token)
        self.get_assignable_roles.set_access_token(access_token)
        self.hl7_connector_record.set_access_token(access_token)
        self.installer_token.set_access_token(access_token)
        self.integration_pack.set_access_token(access_token)
        self.integration_pack_atom_attachment.set_access_token(access_token)
        self.integration_pack_environment_attachment.set_access_token(access_token)
        self.integration_pack_instance.set_access_token(access_token)
        self.java_rollback.set_access_token(access_token)
        self.java_upgrade.set_access_token(access_token)
        self.merge_request.set_access_token(access_token)
        self.move_queue_request.set_access_token(access_token)
        self.node_offboard.set_access_token(access_token)
        self.odette_connector_record.set_access_token(access_token)
        self.oftp2_connector_record.set_access_token(access_token)
        self.packaged_component.set_access_token(access_token)
        self.packaged_component_manifest.set_access_token(access_token)
        self.persisted_process_properties.set_access_token(access_token)
        self.process.set_access_token(access_token)
        self.process_atom_attachment.set_access_token(access_token)
        self.process_environment_attachment.set_access_token(access_token)
        self.process_log.set_access_token(access_token)
        self.process_schedule_status.set_access_token(access_token)
        self.process_schedules.set_access_token(access_token)
        self.rerun_document.set_access_token(access_token)
        self.role.set_access_token(access_token)
        self.rosetta_net_connector_record.set_access_token(access_token)
        self.runtime_release_schedule.set_access_token(access_token)
        self.cancel_execution.set_access_token(access_token)
        self.shared_server_information.set_access_token(access_token)
        self.shared_web_server.set_access_token(access_token)
        self.throughput_account.set_access_token(access_token)
        self.throughput_account_group.set_access_token(access_token)
        self.tradacoms_connector_record.set_access_token(access_token)
        self.trading_partner_component.set_access_token(access_token)
        self.trading_partner_processing_group.set_access_token(access_token)
        self.x12_connector_record.set_access_token(access_token)
        self.atom_disk_space.set_access_token(access_token)
        self.list_queues.set_access_token(access_token)
        self.listener_status.set_access_token(access_token)
        self.organization_component.set_access_token(access_token)
        self.shared_communication_channel_component.set_access_token(access_token)
        self.account_group_integration_pack.set_access_token(access_token)
        self.publisher_integration_pack.set_access_token(access_token)
        self.release_integration_pack.set_access_token(access_token)
        self.release_integration_pack_status.set_access_token(access_token)
        self.runtime_restart_request.set_access_token(access_token)
        self.refresh_secrets_manager.set_access_token(access_token)
        self.runtime_cloud.set_access_token(access_token)
        self.account_cloud_attachment_summary.set_access_token(access_token)
        self.account_cloud_attachment_properties_default.set_access_token(access_token)
        self.runtime_properties.set_access_token(access_token)
        self.runtime_observability_settings.set_access_token(access_token)
        self.cloud_attachment_secrets_configuration.set_access_token(access_token)

        return self

    def set_basic_auth(self, username: str, password: str):
        """
        Sets the username and password for the entire SDK.
        """
        self.as2_connector_record.set_basic_auth(username=username, password=password)
        self.account.set_basic_auth(username=username, password=password)
        self.account_cloud_attachment_properties.set_basic_auth(
            username=username, password=password
        )
        self.account_cloud_attachment_quota.set_basic_auth(
            username=username, password=password
        )
        self.account_group.set_basic_auth(username=username, password=password)
        self.account_group_account.set_basic_auth(username=username, password=password)
        self.account_group_user_role.set_basic_auth(
            username=username, password=password
        )
        self.account_sso_config.set_basic_auth(username=username, password=password)
        self.account_user_federation.set_basic_auth(
            username=username, password=password
        )
        self.account_user_role.set_basic_auth(username=username, password=password)
        self.api_usage_count.set_basic_auth(username=username, password=password)
        self.atom.set_basic_auth(username=username, password=password)
        self.atom_as2_artifacts.set_basic_auth(username=username, password=password)
        self.atom_connection_field_extension_summary.set_basic_auth(
            username=username, password=password
        )
        self.atom_connector_versions.set_basic_auth(
            username=username, password=password
        )
        self.atom_counters.set_basic_auth(username=username, password=password)
        self.atom_log.set_basic_auth(username=username, password=password)
        self.atom_purge.set_basic_auth(username=username, password=password)
        self.atom_security_policies.set_basic_auth(username=username, password=password)
        self.atom_startup_properties.set_basic_auth(
            username=username, password=password
        )
        self.atom_worker_log.set_basic_auth(username=username, password=password)
        self.audit_log.set_basic_auth(username=username, password=password)
        self.branch.set_basic_auth(username=username, password=password)
        self.change_listener_status.set_basic_auth(username=username, password=password)
        self.clear_queue.set_basic_auth(username=username, password=password)
        self.cloud.set_basic_auth(username=username, password=password)
        self.cloud_attachment_properties.set_basic_auth(
            username=username, password=password
        )
        self.component.set_basic_auth(username=username, password=password)
        self.component_atom_attachment.set_basic_auth(
            username=username, password=password
        )
        self.component_diff_request.set_basic_auth(username=username, password=password)
        self.component_environment_attachment.set_basic_auth(
            username=username, password=password
        )
        self.component_metadata.set_basic_auth(username=username, password=password)
        self.component_reference.set_basic_auth(username=username, password=password)
        self.connection_licensing_report.set_basic_auth(
            username=username, password=password
        )
        self.connector.set_basic_auth(username=username, password=password)
        self.connector_document.set_basic_auth(username=username, password=password)
        self.custom_tracked_field.set_basic_auth(username=username, password=password)
        self.deployed_expired_certificate.set_basic_auth(
            username=username, password=password
        )
        self.deployed_package.set_basic_auth(username=username, password=password)
        self.deployment.set_basic_auth(username=username, password=password)
        self.document_count_account.set_basic_auth(username=username, password=password)
        self.document_count_account_group.set_basic_auth(
            username=username, password=password
        )
        self.edifact_connector_record.set_basic_auth(
            username=username, password=password
        )
        self.edi_custom_connector_record.set_basic_auth(
            username=username, password=password
        )
        self.environment.set_basic_auth(username=username, password=password)
        self.environment_atom_attachment.set_basic_auth(
            username=username, password=password
        )
        self.environment_connection_field_extension_summary.set_basic_auth(
            username=username, password=password
        )
        self.environment_extensions.set_basic_auth(username=username, password=password)
        self.environment_map_extension.set_basic_auth(
            username=username, password=password
        )
        self.environment_map_extension_external_component.set_basic_auth(
            username=username, password=password
        )
        self.environment_map_extension_user_defined_function.set_basic_auth(
            username=username, password=password
        )
        self.environment_map_extension_user_defined_function_summary.set_basic_auth(
            username=username, password=password
        )
        self.environment_map_extensions_summary.set_basic_auth(
            username=username, password=password
        )
        self.environment_role.set_basic_auth(username=username, password=password)
        self.event.set_basic_auth(username=username, password=password)
        self.execution_artifacts.set_basic_auth(username=username, password=password)
        self.execution_connector.set_basic_auth(username=username, password=password)
        self.execution_count_account.set_basic_auth(
            username=username, password=password
        )
        self.execution_count_account_group.set_basic_auth(
            username=username, password=password
        )
        self.execution_record.set_basic_auth(username=username, password=password)
        self.execution_request.set_basic_auth(username=username, password=password)
        self.execution_summary_record.set_basic_auth(
            username=username, password=password
        )
        self.folder.set_basic_auth(username=username, password=password)
        self.generic_connector_record.set_basic_auth(
            username=username, password=password
        )
        self.get_assignable_roles.set_basic_auth(username=username, password=password)
        self.hl7_connector_record.set_basic_auth(username=username, password=password)
        self.installer_token.set_basic_auth(username=username, password=password)
        self.integration_pack.set_basic_auth(username=username, password=password)
        self.integration_pack_atom_attachment.set_basic_auth(
            username=username, password=password
        )
        self.integration_pack_environment_attachment.set_basic_auth(
            username=username, password=password
        )
        self.integration_pack_instance.set_basic_auth(
            username=username, password=password
        )
        self.java_rollback.set_basic_auth(username=username, password=password)
        self.java_upgrade.set_basic_auth(username=username, password=password)
        self.merge_request.set_basic_auth(username=username, password=password)
        self.move_queue_request.set_basic_auth(username=username, password=password)
        self.node_offboard.set_basic_auth(username=username, password=password)
        self.odette_connector_record.set_basic_auth(
            username=username, password=password
        )
        self.oftp2_connector_record.set_basic_auth(username=username, password=password)
        self.packaged_component.set_basic_auth(username=username, password=password)
        self.packaged_component_manifest.set_basic_auth(
            username=username, password=password
        )
        self.persisted_process_properties.set_basic_auth(
            username=username, password=password
        )
        self.process.set_basic_auth(username=username, password=password)
        self.process_atom_attachment.set_basic_auth(
            username=username, password=password
        )
        self.process_environment_attachment.set_basic_auth(
            username=username, password=password
        )
        self.process_log.set_basic_auth(username=username, password=password)
        self.process_schedule_status.set_basic_auth(
            username=username, password=password
        )
        self.process_schedules.set_basic_auth(username=username, password=password)
        self.rerun_document.set_basic_auth(username=username, password=password)
        self.role.set_basic_auth(username=username, password=password)
        self.rosetta_net_connector_record.set_basic_auth(
            username=username, password=password
        )
        self.runtime_release_schedule.set_basic_auth(
            username=username, password=password
        )
        self.cancel_execution.set_basic_auth(username=username, password=password)
        self.shared_server_information.set_basic_auth(
            username=username, password=password
        )
        self.shared_web_server.set_basic_auth(username=username, password=password)
        self.throughput_account.set_basic_auth(username=username, password=password)
        self.throughput_account_group.set_basic_auth(
            username=username, password=password
        )
        self.tradacoms_connector_record.set_basic_auth(
            username=username, password=password
        )
        self.trading_partner_component.set_basic_auth(
            username=username, password=password
        )
        self.trading_partner_processing_group.set_basic_auth(
            username=username, password=password
        )
        self.x12_connector_record.set_basic_auth(username=username, password=password)
        self.atom_disk_space.set_basic_auth(username=username, password=password)
        self.list_queues.set_basic_auth(username=username, password=password)
        self.listener_status.set_basic_auth(username=username, password=password)
        self.organization_component.set_basic_auth(username=username, password=password)
        self.shared_communication_channel_component.set_basic_auth(
            username=username, password=password
        )
        self.account_group_integration_pack.set_basic_auth(
            username=username, password=password
        )
        self.publisher_integration_pack.set_basic_auth(
            username=username, password=password
        )
        self.release_integration_pack.set_basic_auth(
            username=username, password=password
        )
        self.release_integration_pack_status.set_basic_auth(
            username=username, password=password
        )
        self.runtime_restart_request.set_basic_auth(
            username=username, password=password
        )
        self.refresh_secrets_manager.set_basic_auth(
            username=username, password=password
        )
        self.runtime_cloud.set_basic_auth(username=username, password=password)
        self.account_cloud_attachment_summary.set_basic_auth(
            username=username, password=password
        )
        self.account_cloud_attachment_properties_default.set_basic_auth(
            username=username, password=password
        )
        self.runtime_properties.set_basic_auth(username=username, password=password)
        self.runtime_observability_settings.set_basic_auth(
            username=username, password=password
        )
        self.cloud_attachment_secrets_configuration.set_basic_auth(
            username=username, password=password
        )

        return self

    def set_timeout(self, timeout: int):
        """
        Sets the timeout for the entire SDK.

        :param int timeout: The timeout (ms) to be set.
        :return: The SDK instance.
        """
        self.as2_connector_record.set_timeout(timeout)
        self.account.set_timeout(timeout)
        self.account_cloud_attachment_properties.set_timeout(timeout)
        self.account_cloud_attachment_quota.set_timeout(timeout)
        self.account_group.set_timeout(timeout)
        self.account_group_account.set_timeout(timeout)
        self.account_group_user_role.set_timeout(timeout)
        self.account_sso_config.set_timeout(timeout)
        self.account_user_federation.set_timeout(timeout)
        self.account_user_role.set_timeout(timeout)
        self.api_usage_count.set_timeout(timeout)
        self.atom.set_timeout(timeout)
        self.atom_as2_artifacts.set_timeout(timeout)
        self.atom_connection_field_extension_summary.set_timeout(timeout)
        self.atom_connector_versions.set_timeout(timeout)
        self.atom_counters.set_timeout(timeout)
        self.atom_log.set_timeout(timeout)
        self.atom_purge.set_timeout(timeout)
        self.atom_security_policies.set_timeout(timeout)
        self.atom_startup_properties.set_timeout(timeout)
        self.atom_worker_log.set_timeout(timeout)
        self.audit_log.set_timeout(timeout)
        self.branch.set_timeout(timeout)
        self.change_listener_status.set_timeout(timeout)
        self.clear_queue.set_timeout(timeout)
        self.cloud.set_timeout(timeout)
        self.cloud_attachment_properties.set_timeout(timeout)
        self.component.set_timeout(timeout)
        self.component_atom_attachment.set_timeout(timeout)
        self.component_diff_request.set_timeout(timeout)
        self.component_environment_attachment.set_timeout(timeout)
        self.component_metadata.set_timeout(timeout)
        self.component_reference.set_timeout(timeout)
        self.connection_licensing_report.set_timeout(timeout)
        self.connector.set_timeout(timeout)
        self.connector_document.set_timeout(timeout)
        self.custom_tracked_field.set_timeout(timeout)
        self.deployed_expired_certificate.set_timeout(timeout)
        self.deployed_package.set_timeout(timeout)
        self.deployment.set_timeout(timeout)
        self.document_count_account.set_timeout(timeout)
        self.document_count_account_group.set_timeout(timeout)
        self.edifact_connector_record.set_timeout(timeout)
        self.edi_custom_connector_record.set_timeout(timeout)
        self.environment.set_timeout(timeout)
        self.environment_atom_attachment.set_timeout(timeout)
        self.environment_connection_field_extension_summary.set_timeout(timeout)
        self.environment_extensions.set_timeout(timeout)
        self.environment_map_extension.set_timeout(timeout)
        self.environment_map_extension_external_component.set_timeout(timeout)
        self.environment_map_extension_user_defined_function.set_timeout(timeout)
        self.environment_map_extension_user_defined_function_summary.set_timeout(
            timeout
        )
        self.environment_map_extensions_summary.set_timeout(timeout)
        self.environment_role.set_timeout(timeout)
        self.event.set_timeout(timeout)
        self.execution_artifacts.set_timeout(timeout)
        self.execution_connector.set_timeout(timeout)
        self.execution_count_account.set_timeout(timeout)
        self.execution_count_account_group.set_timeout(timeout)
        self.execution_record.set_timeout(timeout)
        self.execution_request.set_timeout(timeout)
        self.execution_summary_record.set_timeout(timeout)
        self.folder.set_timeout(timeout)
        self.generic_connector_record.set_timeout(timeout)
        self.get_assignable_roles.set_timeout(timeout)
        self.hl7_connector_record.set_timeout(timeout)
        self.installer_token.set_timeout(timeout)
        self.integration_pack.set_timeout(timeout)
        self.integration_pack_atom_attachment.set_timeout(timeout)
        self.integration_pack_environment_attachment.set_timeout(timeout)
        self.integration_pack_instance.set_timeout(timeout)
        self.java_rollback.set_timeout(timeout)
        self.java_upgrade.set_timeout(timeout)
        self.merge_request.set_timeout(timeout)
        self.move_queue_request.set_timeout(timeout)
        self.node_offboard.set_timeout(timeout)
        self.odette_connector_record.set_timeout(timeout)
        self.oftp2_connector_record.set_timeout(timeout)
        self.packaged_component.set_timeout(timeout)
        self.packaged_component_manifest.set_timeout(timeout)
        self.persisted_process_properties.set_timeout(timeout)
        self.process.set_timeout(timeout)
        self.process_atom_attachment.set_timeout(timeout)
        self.process_environment_attachment.set_timeout(timeout)
        self.process_log.set_timeout(timeout)
        self.process_schedule_status.set_timeout(timeout)
        self.process_schedules.set_timeout(timeout)
        self.rerun_document.set_timeout(timeout)
        self.role.set_timeout(timeout)
        self.rosetta_net_connector_record.set_timeout(timeout)
        self.runtime_release_schedule.set_timeout(timeout)
        self.cancel_execution.set_timeout(timeout)
        self.shared_server_information.set_timeout(timeout)
        self.shared_web_server.set_timeout(timeout)
        self.throughput_account.set_timeout(timeout)
        self.throughput_account_group.set_timeout(timeout)
        self.tradacoms_connector_record.set_timeout(timeout)
        self.trading_partner_component.set_timeout(timeout)
        self.trading_partner_processing_group.set_timeout(timeout)
        self.x12_connector_record.set_timeout(timeout)
        self.atom_disk_space.set_timeout(timeout)
        self.list_queues.set_timeout(timeout)
        self.listener_status.set_timeout(timeout)
        self.organization_component.set_timeout(timeout)
        self.shared_communication_channel_component.set_timeout(timeout)
        self.account_group_integration_pack.set_timeout(timeout)
        self.publisher_integration_pack.set_timeout(timeout)
        self.release_integration_pack.set_timeout(timeout)
        self.release_integration_pack_status.set_timeout(timeout)
        self.runtime_restart_request.set_timeout(timeout)
        self.refresh_secrets_manager.set_timeout(timeout)
        self.runtime_cloud.set_timeout(timeout)
        self.account_cloud_attachment_summary.set_timeout(timeout)
        self.account_cloud_attachment_properties_default.set_timeout(timeout)
        self.runtime_properties.set_timeout(timeout)
        self.runtime_observability_settings.set_timeout(timeout)
        self.cloud_attachment_secrets_configuration.set_timeout(timeout)

        return self

    def set_account_id(self, account_id: str):
        """
        Sets the account_id server variable for the entire SDK.

        :param str account_id: The account_id to be set.
        :return: The SDK instance.
        """
        self._base_url_account_id = account_id
        self.set_base_url(self._base_url)
        return self


# c029837e0e474b76bc487506e8799df5e3335891efe4fb02bda7a1441840310c




from __future__ import annotations
from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .contact_info import ContactInfo
from .partner_communication import PartnerCommunication
from .partner_document_types import PartnerDocumentTypes
from .partner_info import PartnerInfo


class TradingPartnerComponentClassification(Enum):
    """An enumeration representing different categories.

    :cvar TRADINGPARTNER: "tradingpartner"
    :vartype TRADINGPARTNER: str
    :cvar MYCOMPANY: "mycompany"
    :vartype MYCOMPANY: str
    """

    TRADINGPARTNER = "tradingpartner"
    MYCOMPANY = "mycompany"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                TradingPartnerComponentClassification._member_map_.values(),
            )
        )


class TradingPartnerComponentStandard(Enum):
    """An enumeration representing different categories.

    :cvar X12: "x12"
    :vartype X12: str
    :cvar EDIFACT: "edifact"
    :vartype EDIFACT: str
    :cvar HL7: "hl7"
    :vartype HL7: str
    :cvar CUSTOM: "custom"
    :vartype CUSTOM: str
    :cvar ROSETTANET: "rosettanet"
    :vartype ROSETTANET: str
    :cvar TRADACOMS: "tradacoms"
    :vartype TRADACOMS: str
    :cvar ODETTE: "odette"
    :vartype ODETTE: str
    """

    X12 = "x12"
    EDIFACT = "edifact"
    HL7 = "hl7"
    CUSTOM = "custom"
    ROSETTANET = "rosettanet"
    TRADACOMS = "tradacoms"
    ODETTE = "odette"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value, TradingPartnerComponentStandard._member_map_.values()
            )
        )


@JsonMap(
    {
        "contact_info": "ContactInfo",
        "partner_communication": "PartnerCommunication",
        "partner_communication_types": "PartnerCommunicationTypes",
        "partner_document_types": "PartnerDocumentTypes",
        "partner_info": "PartnerInfo",
        "component_id": "componentId",
        "component_name": "componentName",
        "folder_id": "folderId",
        "folder_name": "folderName",
        "organization_id": "organizationId",
        "branch_id": "branchId",
        "branch_name": "branchName",
    }
)
class TradingPartnerComponent(BaseModel):
    """TradingPartnerComponent

    :param contact_info: contact_info, defaults to None
    :type contact_info: ContactInfo, optional
    :param partner_communication: partner_communication, defaults to None
    :type partner_communication: PartnerCommunication, optional
    :param partner_communication_types: partner_communication_types, defaults to None
    :type partner_communication_types: List[str], optional
    :param partner_document_types: partner_document_types, defaults to None
    :type partner_document_types: PartnerDocumentTypes, optional
    :param partner_info: partner_info, defaults to None
    :type partner_info: PartnerInfo, optional
    :param classification: classification, defaults to None
    :type classification: TradingPartnerComponentClassification, optional
    :param component_id: component_id, defaults to None
    :type component_id: str, optional
    :param component_name: component_name, defaults to None
    :type component_name: str, optional
    :param deleted: deleted, defaults to None
    :type deleted: bool, optional
    :param description: description, defaults to None
    :type description: str, optional
    :param folder_id: folder_id, defaults to None
    :type folder_id: int, optional
    :param folder_name: folder_name, defaults to None
    :type folder_name: str, optional
    :param identifier: identifier, defaults to None
    :type identifier: str, optional
    :param organization_id: organization_id, defaults to None
    :type organization_id: str, optional
    :param standard: standard, defaults to None
    :type standard: TradingPartnerComponentStandard, optional
    :param branch_id: branch_id, defaults to None
    :type branch_id: str, optional
    :param branch_name: branch_name, defaults to None
    :type branch_name: str, optional
    """

    def __init__(
        self,
        contact_info: ContactInfo = SENTINEL,
        partner_communication: PartnerCommunication = SENTINEL,
        partner_document_types: PartnerDocumentTypes = SENTINEL,
        partner_info: PartnerInfo = SENTINEL,
        partner_communication_types: List[str] = SENTINEL,
        classification: TradingPartnerComponentClassification = SENTINEL,
        component_id: str = SENTINEL,
        component_name: str = SENTINEL,
        deleted: bool = SENTINEL,
        description: str = SENTINEL,
        folder_id: int = SENTINEL,
        folder_name: str = SENTINEL,
        identifier: str = SENTINEL,
        organization_id: str = SENTINEL,
        standard: TradingPartnerComponentStandard = SENTINEL,
        branch_id: str = SENTINEL,
        branch_name: str = SENTINEL,
        **kwargs,
    ):
        """TradingPartnerComponent

        :param contact_info: contact_info, defaults to None
        :type contact_info: ContactInfo, optional
        :param partner_communication: partner_communication, defaults to None
        :type partner_communication: PartnerCommunication, optional
        :param partner_communication_types: partner_communication_types, defaults to None
        :type partner_communication_types: List[str], optional
        :param partner_document_types: partner_document_types, defaults to None
        :type partner_document_types: PartnerDocumentTypes, optional
        :param partner_info: partner_info, defaults to None
        :type partner_info: PartnerInfo, optional
        :param classification: classification, defaults to None
        :type classification: TradingPartnerComponentClassification, optional
        :param component_id: component_id, defaults to None
        :type component_id: str, optional
        :param component_name: component_name, defaults to None
        :type component_name: str, optional
        :param deleted: deleted, defaults to None
        :type deleted: bool, optional
        :param description: description, defaults to None
        :type description: str, optional
        :param folder_id: folder_id, defaults to None
        :type folder_id: int, optional
        :param folder_name: folder_name, defaults to None
        :type folder_name: str, optional
        :param identifier: identifier, defaults to None
        :type identifier: str, optional
        :param organization_id: organization_id, defaults to None
        :type organization_id: str, optional
        :param standard: standard, defaults to None
        :type standard: TradingPartnerComponentStandard, optional
        :param branch_id: branch_id, defaults to None
        :type branch_id: str, optional
        :param branch_name: branch_name, defaults to None
        :type branch_name: str, optional
        """
        if contact_info is not SENTINEL:
            self.contact_info = self._define_object(contact_info, ContactInfo)
        if partner_communication is not SENTINEL:
            self.partner_communication = self._define_object(
                partner_communication, PartnerCommunication
            )
        if partner_communication_types is not SENTINEL:
            self.partner_communication_types = partner_communication_types
        if partner_document_types is not SENTINEL:
            self.partner_document_types = self._define_object(
                partner_document_types, PartnerDocumentTypes
            )
        if partner_info is not SENTINEL:
            self.partner_info = self._define_object(partner_info, PartnerInfo)
        if classification is not SENTINEL:
            self.classification = self._enum_matching(
                classification,
                TradingPartnerComponentClassification.list(),
                "classification",
            )
        if component_id is not SENTINEL:
            self.component_id = component_id
        if component_name is not SENTINEL:
            self.component_name = component_name
        if deleted is not SENTINEL:
            self.deleted = deleted
        if description is not SENTINEL:
            self.description = description
        if folder_id is not SENTINEL:
            self.folder_id = folder_id
        if folder_name is not SENTINEL:
            self.folder_name = folder_name
        if identifier is not SENTINEL:
            self.identifier = identifier
        if organization_id is not SENTINEL:
            self.organization_id = organization_id
        if standard is not SENTINEL:
            self.standard = self._enum_matching(
                standard, TradingPartnerComponentStandard.list(), "standard"
            )
        if branch_id is not SENTINEL:
            self.branch_id = branch_id
        if branch_name is not SENTINEL:
            self.branch_name = branch_name
        self._kwargs = kwargs




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .account_cloud_attachment_summary_simple_expression import AccountCloudAttachmentSummarySimpleExpression
from .account_cloud_attachment_summary_grouping_expression import AccountCloudAttachmentSummaryGroupingExpression


class AccountCloudAttachmentSummaryExpressionGuard(OneOfBaseModel):
    class_list = {
        "AccountCloudAttachmentSummarySimpleExpression": AccountCloudAttachmentSummarySimpleExpression,
        "AccountCloudAttachmentSummaryGroupingExpression": AccountCloudAttachmentSummaryGroupingExpression,
    }


AccountCloudAttachmentSummaryExpression = Union[AccountCloudAttachmentSummarySimpleExpression, AccountCloudAttachmentSummaryGroupingExpression]




from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class ClusterNetworkTransportType(Enum):
    """An enumeration representing different categories.

    :cvar MULTICAST: "MULTICAST"
    :vartype MULTICAST: str
    :cvar UNICAST: "UNICAST"
    :vartype UNICAST: str
    """

    MULTICAST = "MULTICAST"
    UNICAST = "UNICAST"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, ClusterNetworkTransportType._member_map_.values())
        )


class DebugLogLevelThreshold(Enum):
    """An enumeration representing different categories.

    :cvar DEBUG: "DEBUG"
    :vartype DEBUG: str
    :cvar INFO: "INFO"
    :vartype INFO: str
    :cvar OFF: "OFF"
    :vartype OFF: str
    :cvar SEVERE: "SEVERE"
    :vartype SEVERE: str
    :cvar WARNING: "WARNING"
    :vartype WARNING: str
    """

    DEBUG = "DEBUG"
    INFO = "INFO"
    OFF = "OFF"
    SEVERE = "SEVERE"
    WARNING = "WARNING"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, DebugLogLevelThreshold._member_map_.values())
        )


class ExecuteProcessesAsForkedJvms(Enum):
    """An enumeration representing different categories.

    :cvar ELASTIC: "ELASTIC"
    :vartype ELASTIC: str
    :cvar MULTI_PROCESS: "MULTI_PROCESS"
    :vartype MULTI_PROCESS: str
    :cvar MULTI_THREAD: "MULTI_THREAD"
    :vartype MULTI_THREAD: str
    """

    ELASTIC = "ELASTIC"
    MULTI_PROCESS = "MULTI_PROCESS"
    MULTI_THREAD = "MULTI_THREAD"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, ExecuteProcessesAsForkedJvms._member_map_.values())
        )


class ListenerStartupMode(Enum):
    """An enumeration representing different categories.

    :cvar ALL: "ALL"
    :vartype ALL: str
    :cvar MULTITENANT_ONLY: "MULTITENANT_ONLY"
    :vartype MULTITENANT_ONLY: str
    :cvar NONE: "NONE"
    :vartype NONE: str
    :cvar EFFECTIVE_SINGLE_TENANT_ONLY: "EFFECTIVE_SINGLE_TENANT_ONLY"
    :vartype EFFECTIVE_SINGLE_TENANT_ONLY: str
    """

    ALL = "ALL"
    MULTITENANT_ONLY = "MULTITENANT_ONLY"
    NONE = "NONE"
    EFFECTIVE_SINGLE_TENANT_ONLY = "EFFECTIVE_SINGLE_TENANT_ONLY"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, ListenerStartupMode._member_map_.values())
        )


class SecurityPolicy(Enum):
    """An enumeration representing different categories.

    :cvar HIGH: "HIGH"
    :vartype HIGH: str
    :cvar LOW: "LOW"
    :vartype LOW: str
    :cvar CUSTOM: "CUSTOM"
    :vartype CUSTOM: str
    """

    HIGH = "HIGH"
    LOW = "LOW"
    CUSTOM = "CUSTOM"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, SecurityPolicy._member_map_.values())
        )


class StandardErrorLogLevel(Enum):
    """An enumeration representing different categories.

    :cvar OFF: "OFF"
    :vartype OFF: str
    :cvar WARNING: "WARNING"
    :vartype WARNING: str
    :cvar SEVERE: "SEVERE"
    :vartype SEVERE: str
    """

    OFF = "OFF"
    WARNING = "WARNING"
    SEVERE = "SEVERE"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(lambda x: x.value, StandardErrorLogLevel._member_map_.values())
        )


@JsonMap(
    {
        "account_working_data_directories": "accountWorkingDataDirectories",
        "allow_browsing": "allowBrowsing",
        "allow_user_logs": "allowUserLogs",
        "archive_processed_documents": "archiveProcessedDocuments",
        "async_message_poller_timeout_for_cluster_scale_down": "asyncMessagePollerTimeoutForClusterScaleDown",
        "auto_restart_on_out_of_memory": "autoRestartOnOutOfMemory",
        "auto_restart_on_too_many_files_error": "autoRestartOnTooManyFilesError",
        "aws_secrets_manager": "awsSecretsManager",
        "aws_secrets_manager_region": "awsSecretsManagerRegion",
        "azure_secrets_manager": "azureSecretsManager",
        "clean_up_custom_script_engine_data_on_completion": "cleanUpCustomScriptEngineDataOnCompletion",
        "cloud_partition_replicas": "cloudPartitionReplicas",
        "cloud_partition_size": "cloudPartitionSize",
        "cluster_bootstrap_timeout": "clusterBootstrapTimeout",
        "cluster_network_bind_address": "clusterNetworkBindAddress",
        "cluster_network_transport_type": "clusterNetworkTransportType",
        "cluster_problem_automatic_delete_delay": "clusterProblemAutomaticDeleteDelay",
        "cluster_problem_automatic_shutdown_delay": "clusterProblemAutomaticShutdownDelay",
        "cluster_rolling_restart_percentage": "clusterRollingRestartPercentage",
        "compress_history_after_x_days": "compressHistoryAfterXDays",
        "connector_browsing_idle_timeout": "connectorBrowsingIdleTimeout",
        "connector_browsing_max_thread_count": "connectorBrowsingMaxThreadCount",
        "connector_browsing_maximum_browse_time": "connectorBrowsingMaximumBrowseTime",
        "connector_browsing_time_to_live": "connectorBrowsingTimeToLive",
        "connector_server_startup_timeout": "connectorServerStartupTimeout",
        "connector_trace_logging": "connectorTraceLogging",
        "container_force_restart": "containerForceRestart",
        "container_host_name": "containerHostName",
        "container_name": "containerName",
        "container_purge_days": "containerPurgeDays",
        "container_purge_immediately": "containerPurgeImmediately",
        "control_id_cache_idle_timeout": "controlIdCacheIdleTimeout",
        "control_id_cache_time_to_live": "controlIdCacheTimeToLive",
        "counter_file_lock_retry": "counterFileLockRetry",
        "counter_lock_retry_maximum_retries": "counterLockRetryMaximumRetries",
        "counter_lock_retry_wait_time": "counterLockRetryWaitTime",
        "customized_procbrowser_script_file_name": "customizedProcbrowserScriptFileName",
        "customized_procrunner_script_file_name": "customizedProcrunnerScriptFileName",
        "customized_procworker_script_file_name": "customizedProcworkerScriptFileName",
        "customized_restart_script_file_name": "customizedRestartScriptFileName",
        "debug_log_level_threshold": "debugLogLevelThreshold",
        "debug_logging": "debugLogging",
        "decommission_time_for_post_pause_sleep": "decommissionTimeForPostPauseSleep",
        "default_time_zone_for_account_schedules": "defaultTimeZoneForAccountSchedules",
        "disk_space_monitoring": "diskSpaceMonitoring",
        "disk_space_monitoring_account_auto_suspension": "diskSpaceMonitoringAccountAutoSuspension",
        "disk_space_monitoring_frequency": "diskSpaceMonitoringFrequency",
        "disk_space_monitoring_threads": "diskSpaceMonitoringThreads",
        "disk_space_monitoring_verbose_logging": "diskSpaceMonitoringVerboseLogging",
        "disk_space_warning_limit": "diskSpaceWarningLimit",
        "dump_to_file_when_exceeding_open_file_threshold": "dumpToFileWhenExceedingOpenFileThreshold",
        "early_stale_execution_worker_ttl_percentage": "earlyStaleExecutionWorkerTtlPercentage",
        "elastic_worker_directory_level": "elasticWorkerDirectoryLevel",
        "elastic_worker_metrics_polling_period": "elasticWorkerMetricsPollingPeriod",
        "execute_processes_as_forked_jvms": "executeProcessesAsForkedJvms",
        "execution_worker_idle_timeout": "executionWorkerIdleTimeout",
        "execution_worker_local_port_range": "executionWorkerLocalPortRange",
        "execution_worker_pending_updates_queue_size": "executionWorkerPendingUpdatesQueueSize",
        "execution_worker_startup_timeout": "executionWorkerStartupTimeout",
        "execution_worker_thread_pool_idle_timeout": "executionWorkerThreadPoolIdleTimeout",
        "execution_worker_time_to_live": "executionWorkerTimeToLive",
        "execution_workers_enabled": "executionWorkersEnabled",
        "external_hostname": "externalHostname",
        "force_restart_override_for_cluster_scale_down": "forceRestartOverrideForClusterScaleDown",
        "force_start_shared_web_server": "forceStartSharedWebServer",
        "generate_heap_dump_on_low_memory": "generateHeapDumpOnLowMemory",
        "https_protocols": "httpsProtocols",
        "initial_hosts_for_unicast": "initialHostsForUnicast",
        "jgroups_debug_logging": "jgroupsDebugLogging",
        "listener_startup_mode": "listenerStartupMode",
        "logger_queue_size": "loggerQueueSize",
        "logger_timeout": "loggerTimeout",
        "low_latency_warning_threshold": "lowLatencyWarningThreshold",
        "low_memory_mode_threshold": "lowMemoryModeThreshold",
        "low_remaining_open_files_threshold": "lowRemainingOpenFilesThreshold",
        "mapping_expand_child_elements_legacy": "mappingExpandChildElementsLegacy",
        "max_cached_control_ids": "maxCachedControlIds",
        "max_cached_transaction_keys": "maxCachedTransactionKeys",
        "max_document_elements_cache_size": "maxDocumentElementsCacheSize",
        "max_execution_threads_per_connector_browser": "maxExecutionThreadsPerConnectorBrowser",
        "max_execution_threads_per_execution_worker": "maxExecutionThreadsPerExecutionWorker",
        "max_execution_threads_per_forked_execution": "maxExecutionThreadsPerForkedExecution",
        "max_flow_control_units": "maxFlowControlUnits",
        "max_forked_execution_time_in_cloud": "maxForkedExecutionTimeInCloud",
        "max_number_of_active_batches_per_listener": "maxNumberOfActiveBatchesPerListener",
        "max_queued_executions_per_node": "maxQueuedExecutionsPerNode",
        "max_queued_forked_executions_per_node": "maxQueuedForkedExecutionsPerNode",
        "max_simultaneous_executions_per_node": "maxSimultaneousExecutionsPerNode",
        "max_simultaneous_forked_executions_per_node": "maxSimultaneousForkedExecutionsPerNode",
        "max_simultaneous_forked_jvms_per_node": "maxSimultaneousForkedJvmsPerNode",
        "max_size_for_update_operation": "maxSizeForUpdateOperation",
        "milliseconds_logging": "millisecondsLogging",
        "min_number_of_hosts_for_unicast_autodetect": "minNumberOfHostsForUnicastAutodetect",
        "monitor_number_of_open_files": "monitorNumberOfOpenFiles",
        "multicast_address": "multicastAddress",
        "multicast_port": "multicastPort",
        "persisted_connector_cache": "persistedConnectorCache",
        "process_execution_directory_level": "processExecutionDirectoryLevel",
        "processed_document_archive_directory": "processedDocumentArchiveDirectory",
        "proxy_user_id": "proxyUserId",
        "purge_manager": "purgeManager",
        "purge_manager_threads": "purgeManagerThreads",
        "purge_schedule_for_components": "purgeScheduleForComponents",
        "purge_schedule_for_logs": "purgeScheduleForLogs",
        "purge_schedule_for_processed_documents": "purgeScheduleForProcessedDocuments",
        "purge_schedule_for_temporary_data": "purgeScheduleForTemporaryData",
        "rolling_restart_force_timeout": "rollingRestartForceTimeout",
        "rolling_restart_next_in_line_timeout": "rollingRestartNextInLineTimeout",
        "runtime_data_directory_level": "runtimeDataDirectoryLevel",
        "runtime_pending_shutdown_delay": "runtimePendingShutdownDelay",
        "save_swagger_template_in_work_folder": "saveSwaggerTemplateInWorkFolder",
        "security_policy": "securityPolicy",
        "sequential_processing_of_custom_script_engine_data": "sequentialProcessingOfCustomScriptEngineData",
        "show_runtime_icon_in_system_tray": "showRuntimeIconInSystemTray",
        "ssl_debug_logging": "sslDebugLogging",
        "standard_error_log_level": "standardErrorLogLevel",
        "standard_output_and_error_logging": "standardOutputAndErrorLogging",
        "tcp_port_for_unicast": "tcpPortForUnicast",
        "threads_for_account_initialization": "threadsForAccountInitialization",
        "threads_for_account_initialization_during_starting_and_stopping_plugins": "threadsForAccountInitializationDuringStartingAndStoppingPlugins",
        "threads_for_recovering_executions_during_container_startup": "threadsForRecoveringExecutionsDuringContainerStartup",
        "threads_for_runtime_scheduling": "threadsForRuntimeScheduling",
        "threads_for_runtime_to_platform_messages": "threadsForRuntimeToPlatformMessages",
        "threads_for_runtime_to_platform_polling": "threadsForRuntimeToPlatformPolling",
        "threads_for_runtime_to_runtime_messages": "threadsForRuntimeToRuntimeMessages",
        "timeout_for_escalating_cluster_issue": "timeoutForEscalatingClusterIssue",
        "timeout_for_queued_executions_per_node": "timeoutForQueuedExecutionsPerNode",
        "timeout_for_queued_forked_executions_per_node": "timeoutForQueuedForkedExecutionsPerNode",
        "trace_logging": "traceLogging",
        "use_local_storage_for_runtime_assets": "useLocalStorageForRuntimeAssets",
        "worker_heartbeat_timeout": "workerHeartbeatTimeout",
        "working_data_local_storage_directory": "workingDataLocalStorageDirectory",
        "xml_entity_processing": "xmlEntityProcessing",
        "xml_external_entity_processing": "xmlExternalEntityProcessing",
    }
)
class StandardProperties(BaseModel):
    """StandardProperties

    :param account_working_data_directories: account_working_data_directories, defaults to None
    :type account_working_data_directories: str, optional
    :param allow_browsing: allow_browsing, defaults to None
    :type allow_browsing: bool, optional
    :param allow_user_logs: allow_user_logs, defaults to None
    :type allow_user_logs: bool, optional
    :param archive_processed_documents: archive_processed_documents, defaults to None
    :type archive_processed_documents: bool, optional
    :param async_message_poller_timeout_for_cluster_scale_down: async_message_poller_timeout_for_cluster_scale_down, defaults to None
    :type async_message_poller_timeout_for_cluster_scale_down: int, optional
    :param auto_restart_on_out_of_memory: auto_restart_on_out_of_memory, defaults to None
    :type auto_restart_on_out_of_memory: bool, optional
    :param auto_restart_on_too_many_files_error: auto_restart_on_too_many_files_error, defaults to None
    :type auto_restart_on_too_many_files_error: bool, optional
    :param aws_secrets_manager: aws_secrets_manager, defaults to None
    :type aws_secrets_manager: bool, optional
    :param aws_secrets_manager_region: aws_secrets_manager_region, defaults to None
    :type aws_secrets_manager_region: str, optional
    :param azure_secrets_manager: azure_secrets_manager, defaults to None
    :type azure_secrets_manager: bool, optional
    :param clean_up_custom_script_engine_data_on_completion: clean_up_custom_script_engine_data_on_completion, defaults to None
    :type clean_up_custom_script_engine_data_on_completion: bool, optional
    :param cloud_partition_replicas: cloud_partition_replicas, defaults to None
    :type cloud_partition_replicas: int, optional
    :param cloud_partition_size: cloud_partition_size, defaults to None
    :type cloud_partition_size: int, optional
    :param cluster_bootstrap_timeout: cluster_bootstrap_timeout, defaults to None
    :type cluster_bootstrap_timeout: int, optional
    :param cluster_network_bind_address: cluster_network_bind_address, defaults to None
    :type cluster_network_bind_address: str, optional
    :param cluster_network_transport_type: cluster_network_transport_type, defaults to None
    :type cluster_network_transport_type: ClusterNetworkTransportType, optional
    :param cluster_problem_automatic_delete_delay: cluster_problem_automatic_delete_delay, defaults to None
    :type cluster_problem_automatic_delete_delay: int, optional
    :param cluster_problem_automatic_shutdown_delay: cluster_problem_automatic_shutdown_delay, defaults to None
    :type cluster_problem_automatic_shutdown_delay: int, optional
    :param cluster_rolling_restart_percentage: cluster_rolling_restart_percentage, defaults to None
    :type cluster_rolling_restart_percentage: int, optional
    :param compress_history_after_x_days: compress_history_after_x_days, defaults to None
    :type compress_history_after_x_days: int, optional
    :param connector_browsing_idle_timeout: connector_browsing_idle_timeout, defaults to None
    :type connector_browsing_idle_timeout: int, optional
    :param connector_browsing_max_thread_count: connector_browsing_max_thread_count, defaults to None
    :type connector_browsing_max_thread_count: int, optional
    :param connector_browsing_maximum_browse_time: connector_browsing_maximum_browse_time, defaults to None
    :type connector_browsing_maximum_browse_time: int, optional
    :param connector_browsing_time_to_live: connector_browsing_time_to_live, defaults to None
    :type connector_browsing_time_to_live: int, optional
    :param connector_server_startup_timeout: connector_server_startup_timeout, defaults to None
    :type connector_server_startup_timeout: int, optional
    :param connector_trace_logging: connector_trace_logging, defaults to None
    :type connector_trace_logging: bool, optional
    :param container_force_restart: container_force_restart, defaults to None
    :type container_force_restart: bool, optional
    :param container_host_name: container_host_name, defaults to None
    :type container_host_name: str, optional
    :param container_name: container_name, defaults to None
    :type container_name: str, optional
    :param container_purge_days: container_purge_days, defaults to None
    :type container_purge_days: int, optional
    :param container_purge_immediately: container_purge_immediately, defaults to None
    :type container_purge_immediately: bool, optional
    :param control_id_cache_idle_timeout: control_id_cache_idle_timeout, defaults to None
    :type control_id_cache_idle_timeout: int, optional
    :param control_id_cache_time_to_live: control_id_cache_time_to_live, defaults to None
    :type control_id_cache_time_to_live: int, optional
    :param counter_file_lock_retry: counter_file_lock_retry, defaults to None
    :type counter_file_lock_retry: bool, optional
    :param counter_lock_retry_maximum_retries: counter_lock_retry_maximum_retries, defaults to None
    :type counter_lock_retry_maximum_retries: int, optional
    :param counter_lock_retry_wait_time: counter_lock_retry_wait_time, defaults to None
    :type counter_lock_retry_wait_time: int, optional
    :param customized_procbrowser_script_file_name: customized_procbrowser_script_file_name, defaults to None
    :type customized_procbrowser_script_file_name: str, optional
    :param customized_procrunner_script_file_name: customized_procrunner_script_file_name, defaults to None
    :type customized_procrunner_script_file_name: str, optional
    :param customized_procworker_script_file_name: customized_procworker_script_file_name, defaults to None
    :type customized_procworker_script_file_name: str, optional
    :param customized_restart_script_file_name: customized_restart_script_file_name, defaults to None
    :type customized_restart_script_file_name: str, optional
    :param debug_log_level_threshold: debug_log_level_threshold, defaults to None
    :type debug_log_level_threshold: DebugLogLevelThreshold, optional
    :param debug_logging: debug_logging, defaults to None
    :type debug_logging: bool, optional
    :param decommission_time_for_post_pause_sleep: decommission_time_for_post_pause_sleep, defaults to None
    :type decommission_time_for_post_pause_sleep: int, optional
    :param default_time_zone_for_account_schedules: default_time_zone_for_account_schedules, defaults to None
    :type default_time_zone_for_account_schedules: str, optional
    :param disk_space_monitoring: disk_space_monitoring, defaults to None
    :type disk_space_monitoring: bool, optional
    :param disk_space_monitoring_account_auto_suspension: disk_space_monitoring_account_auto_suspension, defaults to None
    :type disk_space_monitoring_account_auto_suspension: bool, optional
    :param disk_space_monitoring_frequency: disk_space_monitoring_frequency, defaults to None
    :type disk_space_monitoring_frequency: int, optional
    :param disk_space_monitoring_threads: disk_space_monitoring_threads, defaults to None
    :type disk_space_monitoring_threads: int, optional
    :param disk_space_monitoring_verbose_logging: disk_space_monitoring_verbose_logging, defaults to None
    :type disk_space_monitoring_verbose_logging: bool, optional
    :param disk_space_warning_limit: disk_space_warning_limit, defaults to None
    :type disk_space_warning_limit: int, optional
    :param dump_to_file_when_exceeding_open_file_threshold: dump_to_file_when_exceeding_open_file_threshold, defaults to None
    :type dump_to_file_when_exceeding_open_file_threshold: bool, optional
    :param early_stale_execution_worker_ttl_percentage: early_stale_execution_worker_ttl_percentage, defaults to None
    :type early_stale_execution_worker_ttl_percentage: int, optional
    :param elastic_worker_directory_level: elastic_worker_directory_level, defaults to None
    :type elastic_worker_directory_level: int, optional
    :param elastic_worker_metrics_polling_period: elastic_worker_metrics_polling_period, defaults to None
    :type elastic_worker_metrics_polling_period: int, optional
    :param execute_processes_as_forked_jvms: execute_processes_as_forked_jvms, defaults to None
    :type execute_processes_as_forked_jvms: ExecuteProcessesAsForkedJvms, optional
    :param execution_worker_idle_timeout: execution_worker_idle_timeout, defaults to None
    :type execution_worker_idle_timeout: int, optional
    :param execution_worker_local_port_range: execution_worker_local_port_range, defaults to None
    :type execution_worker_local_port_range: str, optional
    :param execution_worker_pending_updates_queue_size: execution_worker_pending_updates_queue_size, defaults to None
    :type execution_worker_pending_updates_queue_size: int, optional
    :param execution_worker_startup_timeout: execution_worker_startup_timeout, defaults to None
    :type execution_worker_startup_timeout: int, optional
    :param execution_worker_thread_pool_idle_timeout: execution_worker_thread_pool_idle_timeout, defaults to None
    :type execution_worker_thread_pool_idle_timeout: int, optional
    :param execution_worker_time_to_live: execution_worker_time_to_live, defaults to None
    :type execution_worker_time_to_live: int, optional
    :param execution_workers_enabled: execution_workers_enabled, defaults to None
    :type execution_workers_enabled: bool, optional
    :param external_hostname: external_hostname, defaults to None
    :type external_hostname: str, optional
    :param force_restart_override_for_cluster_scale_down: force_restart_override_for_cluster_scale_down, defaults to None
    :type force_restart_override_for_cluster_scale_down: bool, optional
    :param force_start_shared_web_server: force_start_shared_web_server, defaults to None
    :type force_start_shared_web_server: bool, optional
    :param generate_heap_dump_on_low_memory: generate_heap_dump_on_low_memory, defaults to None
    :type generate_heap_dump_on_low_memory: bool, optional
    :param https_protocols: https_protocols, defaults to None
    :type https_protocols: str, optional
    :param initial_hosts_for_unicast: initial_hosts_for_unicast, defaults to None
    :type initial_hosts_for_unicast: str, optional
    :param jgroups_debug_logging: jgroups_debug_logging, defaults to None
    :type jgroups_debug_logging: bool, optional
    :param listener_startup_mode: listener_startup_mode, defaults to None
    :type listener_startup_mode: ListenerStartupMode, optional
    :param logger_queue_size: logger_queue_size, defaults to None
    :type logger_queue_size: int, optional
    :param logger_timeout: logger_timeout, defaults to None
    :type logger_timeout: int, optional
    :param low_latency_warning_threshold: low_latency_warning_threshold, defaults to None
    :type low_latency_warning_threshold: int, optional
    :param low_memory_mode_threshold: low_memory_mode_threshold, defaults to None
    :type low_memory_mode_threshold: str, optional
    :param low_remaining_open_files_threshold: low_remaining_open_files_threshold, defaults to None
    :type low_remaining_open_files_threshold: str, optional
    :param mapping_expand_child_elements_legacy: mapping_expand_child_elements_legacy, defaults to None
    :type mapping_expand_child_elements_legacy: bool, optional
    :param max_cached_control_ids: max_cached_control_ids, defaults to None
    :type max_cached_control_ids: int, optional
    :param max_cached_transaction_keys: max_cached_transaction_keys, defaults to None
    :type max_cached_transaction_keys: int, optional
    :param max_document_elements_cache_size: max_document_elements_cache_size, defaults to None
    :type max_document_elements_cache_size: int, optional
    :param max_execution_threads_per_connector_browser: max_execution_threads_per_connector_browser, defaults to None
    :type max_execution_threads_per_connector_browser: int, optional
    :param max_execution_threads_per_execution_worker: max_execution_threads_per_execution_worker, defaults to None
    :type max_execution_threads_per_execution_worker: int, optional
    :param max_execution_threads_per_forked_execution: max_execution_threads_per_forked_execution, defaults to None
    :type max_execution_threads_per_forked_execution: int, optional
    :param max_flow_control_units: max_flow_control_units, defaults to None
    :type max_flow_control_units: int, optional
    :param max_forked_execution_time_in_cloud: max_forked_execution_time_in_cloud, defaults to None
    :type max_forked_execution_time_in_cloud: int, optional
    :param max_number_of_active_batches_per_listener: max_number_of_active_batches_per_listener, defaults to None
    :type max_number_of_active_batches_per_listener: int, optional
    :param max_queued_executions_per_node: max_queued_executions_per_node, defaults to None
    :type max_queued_executions_per_node: int, optional
    :param max_queued_forked_executions_per_node: max_queued_forked_executions_per_node, defaults to None
    :type max_queued_forked_executions_per_node: int, optional
    :param max_simultaneous_executions_per_node: max_simultaneous_executions_per_node, defaults to None
    :type max_simultaneous_executions_per_node: int, optional
    :param max_simultaneous_forked_executions_per_node: max_simultaneous_forked_executions_per_node, defaults to None
    :type max_simultaneous_forked_executions_per_node: int, optional
    :param max_simultaneous_forked_jvms_per_node: max_simultaneous_forked_jvms_per_node, defaults to None
    :type max_simultaneous_forked_jvms_per_node: int, optional
    :param max_size_for_update_operation: max_size_for_update_operation, defaults to None
    :type max_size_for_update_operation: int, optional
    :param milliseconds_logging: milliseconds_logging, defaults to None
    :type milliseconds_logging: bool, optional
    :param min_number_of_hosts_for_unicast_autodetect: min_number_of_hosts_for_unicast_autodetect, defaults to None
    :type min_number_of_hosts_for_unicast_autodetect: int, optional
    :param monitor_number_of_open_files: monitor_number_of_open_files, defaults to None
    :type monitor_number_of_open_files: bool, optional
    :param multicast_address: multicast_address, defaults to None
    :type multicast_address: str, optional
    :param multicast_port: multicast_port, defaults to None
    :type multicast_port: int, optional
    :param persisted_connector_cache: persisted_connector_cache, defaults to None
    :type persisted_connector_cache: bool, optional
    :param process_execution_directory_level: process_execution_directory_level, defaults to None
    :type process_execution_directory_level: int, optional
    :param processed_document_archive_directory: processed_document_archive_directory, defaults to None
    :type processed_document_archive_directory: str, optional
    :param proxy_user_id: proxy_user_id, defaults to None
    :type proxy_user_id: str, optional
    :param purge_manager: purge_manager, defaults to None
    :type purge_manager: bool, optional
    :param purge_manager_threads: purge_manager_threads, defaults to None
    :type purge_manager_threads: int, optional
    :param purge_schedule_for_components: purge_schedule_for_components, defaults to None
    :type purge_schedule_for_components: str, optional
    :param purge_schedule_for_logs: purge_schedule_for_logs, defaults to None
    :type purge_schedule_for_logs: str, optional
    :param purge_schedule_for_processed_documents: purge_schedule_for_processed_documents, defaults to None
    :type purge_schedule_for_processed_documents: str, optional
    :param purge_schedule_for_temporary_data: purge_schedule_for_temporary_data, defaults to None
    :type purge_schedule_for_temporary_data: str, optional
    :param rolling_restart_force_timeout: rolling_restart_force_timeout, defaults to None
    :type rolling_restart_force_timeout: int, optional
    :param rolling_restart_next_in_line_timeout: rolling_restart_next_in_line_timeout, defaults to None
    :type rolling_restart_next_in_line_timeout: int, optional
    :param runtime_data_directory_level: runtime_data_directory_level, defaults to None
    :type runtime_data_directory_level: int, optional
    :param runtime_pending_shutdown_delay: runtime_pending_shutdown_delay, defaults to None
    :type runtime_pending_shutdown_delay: int, optional
    :param save_swagger_template_in_work_folder: save_swagger_template_in_work_folder, defaults to None
    :type save_swagger_template_in_work_folder: bool, optional
    :param security_policy: security_policy, defaults to None
    :type security_policy: SecurityPolicy, optional
    :param sequential_processing_of_custom_script_engine_data: sequential_processing_of_custom_script_engine_data, defaults to None
    :type sequential_processing_of_custom_script_engine_data: bool, optional
    :param show_runtime_icon_in_system_tray: show_runtime_icon_in_system_tray, defaults to None
    :type show_runtime_icon_in_system_tray: bool, optional
    :param ssl_debug_logging: ssl_debug_logging, defaults to None
    :type ssl_debug_logging: bool, optional
    :param standard_error_log_level: standard_error_log_level, defaults to None
    :type standard_error_log_level: StandardErrorLogLevel, optional
    :param standard_output_and_error_logging: standard_output_and_error_logging, defaults to None
    :type standard_output_and_error_logging: bool, optional
    :param tcp_port_for_unicast: tcp_port_for_unicast, defaults to None
    :type tcp_port_for_unicast: int, optional
    :param threads_for_account_initialization: threads_for_account_initialization, defaults to None
    :type threads_for_account_initialization: int, optional
    :param threads_for_account_initialization_during_starting_and_stopping_plugins: threads_for_account_initialization_during_starting_and_stopping_plugins, defaults to None
    :type threads_for_account_initialization_during_starting_and_stopping_plugins: int, optional
    :param threads_for_recovering_executions_during_container_startup: threads_for_recovering_executions_during_container_startup, defaults to None
    :type threads_for_recovering_executions_during_container_startup: int, optional
    :param threads_for_runtime_scheduling: threads_for_runtime_scheduling, defaults to None
    :type threads_for_runtime_scheduling: int, optional
    :param threads_for_runtime_to_platform_messages: threads_for_runtime_to_platform_messages, defaults to None
    :type threads_for_runtime_to_platform_messages: int, optional
    :param threads_for_runtime_to_platform_polling: threads_for_runtime_to_platform_polling, defaults to None
    :type threads_for_runtime_to_platform_polling: int, optional
    :param threads_for_runtime_to_runtime_messages: threads_for_runtime_to_runtime_messages, defaults to None
    :type threads_for_runtime_to_runtime_messages: int, optional
    :param timeout_for_escalating_cluster_issue: timeout_for_escalating_cluster_issue, defaults to None
    :type timeout_for_escalating_cluster_issue: int, optional
    :param timeout_for_queued_executions_per_node: timeout_for_queued_executions_per_node, defaults to None
    :type timeout_for_queued_executions_per_node: int, optional
    :param timeout_for_queued_forked_executions_per_node: timeout_for_queued_forked_executions_per_node, defaults to None
    :type timeout_for_queued_forked_executions_per_node: int, optional
    :param trace_logging: trace_logging, defaults to None
    :type trace_logging: bool, optional
    :param use_local_storage_for_runtime_assets: use_local_storage_for_runtime_assets, defaults to None
    :type use_local_storage_for_runtime_assets: bool, optional
    :param worker_heartbeat_timeout: worker_heartbeat_timeout, defaults to None
    :type worker_heartbeat_timeout: int, optional
    :param working_data_local_storage_directory: working_data_local_storage_directory, defaults to None
    :type working_data_local_storage_directory: str, optional
    :param xml_entity_processing: xml_entity_processing, defaults to None
    :type xml_entity_processing: bool, optional
    :param xml_external_entity_processing: xml_external_entity_processing, defaults to None
    :type xml_external_entity_processing: bool, optional
    """

    def __init__(
        self,
        account_working_data_directories: str = SENTINEL,
        allow_browsing: bool = SENTINEL,
        allow_user_logs: bool = SENTINEL,
        archive_processed_documents: bool = SENTINEL,
        async_message_poller_timeout_for_cluster_scale_down: int = SENTINEL,
        auto_restart_on_out_of_memory: bool = SENTINEL,
        auto_restart_on_too_many_files_error: bool = SENTINEL,
        aws_secrets_manager: bool = SENTINEL,
        aws_secrets_manager_region: str = SENTINEL,
        azure_secrets_manager: bool = SENTINEL,
        clean_up_custom_script_engine_data_on_completion: bool = SENTINEL,
        cloud_partition_replicas: int = SENTINEL,
        cloud_partition_size: int = SENTINEL,
        cluster_bootstrap_timeout: int = SENTINEL,
        cluster_network_bind_address: str = SENTINEL,
        cluster_network_transport_type: ClusterNetworkTransportType = SENTINEL,
        cluster_problem_automatic_delete_delay: int = SENTINEL,
        cluster_problem_automatic_shutdown_delay: int = SENTINEL,
        cluster_rolling_restart_percentage: int = SENTINEL,
        compress_history_after_x_days: int = SENTINEL,
        connector_browsing_idle_timeout: int = SENTINEL,
        connector_browsing_max_thread_count: int = SENTINEL,
        connector_browsing_maximum_browse_time: int = SENTINEL,
        connector_browsing_time_to_live: int = SENTINEL,
        connector_server_startup_timeout: int = SENTINEL,
        connector_trace_logging: bool = SENTINEL,
        container_force_restart: bool = SENTINEL,
        container_host_name: str = SENTINEL,
        container_name: str = SENTINEL,
        container_purge_days: int = SENTINEL,
        container_purge_immediately: bool = SENTINEL,
        control_id_cache_idle_timeout: int = SENTINEL,
        control_id_cache_time_to_live: int = SENTINEL,
        counter_file_lock_retry: bool = SENTINEL,
        counter_lock_retry_maximum_retries: int = SENTINEL,
        counter_lock_retry_wait_time: int = SENTINEL,
        customized_procbrowser_script_file_name: str = SENTINEL,
        customized_procrunner_script_file_name: str = SENTINEL,
        customized_procworker_script_file_name: str = SENTINEL,
        customized_restart_script_file_name: str = SENTINEL,
        debug_log_level_threshold: DebugLogLevelThreshold = SENTINEL,
        debug_logging: bool = SENTINEL,
        decommission_time_for_post_pause_sleep: int = SENTINEL,
        default_time_zone_for_account_schedules: str = SENTINEL,
        disk_space_monitoring: bool = SENTINEL,
        disk_space_monitoring_account_auto_suspension: bool = SENTINEL,
        disk_space_monitoring_frequency: int = SENTINEL,
        disk_space_monitoring_threads: int = SENTINEL,
        disk_space_monitoring_verbose_logging: bool = SENTINEL,
        disk_space_warning_limit: int = SENTINEL,
        dump_to_file_when_exceeding_open_file_threshold: bool = SENTINEL,
        early_stale_execution_worker_ttl_percentage: int = SENTINEL,
        elastic_worker_directory_level: int = SENTINEL,
        elastic_worker_metrics_polling_period: int = SENTINEL,
        execute_processes_as_forked_jvms: ExecuteProcessesAsForkedJvms = SENTINEL,
        execution_worker_idle_timeout: int = SENTINEL,
        execution_worker_local_port_range: str = SENTINEL,
        execution_worker_pending_updates_queue_size: int = SENTINEL,
        execution_worker_startup_timeout: int = SENTINEL,
        execution_worker_thread_pool_idle_timeout: int = SENTINEL,
        execution_worker_time_to_live: int = SENTINEL,
        execution_workers_enabled: bool = SENTINEL,
        external_hostname: str = SENTINEL,
        force_restart_override_for_cluster_scale_down: bool = SENTINEL,
        force_start_shared_web_server: bool = SENTINEL,
        generate_heap_dump_on_low_memory: bool = SENTINEL,
        https_protocols: str = SENTINEL,
        initial_hosts_for_unicast: str = SENTINEL,
        jgroups_debug_logging: bool = SENTINEL,
        listener_startup_mode: ListenerStartupMode = SENTINEL,
        logger_queue_size: int = SENTINEL,
        logger_timeout: int = SENTINEL,
        low_latency_warning_threshold: int = SENTINEL,
        low_memory_mode_threshold: str = SENTINEL,
        low_remaining_open_files_threshold: str = SENTINEL,
        mapping_expand_child_elements_legacy: bool = SENTINEL,
        max_cached_control_ids: int = SENTINEL,
        max_cached_transaction_keys: int = SENTINEL,
        max_document_elements_cache_size: int = SENTINEL,
        max_execution_threads_per_connector_browser: int = SENTINEL,
        max_execution_threads_per_execution_worker: int = SENTINEL,
        max_execution_threads_per_forked_execution: int = SENTINEL,
        max_flow_control_units: int = SENTINEL,
        max_forked_execution_time_in_cloud: int = SENTINEL,
        max_number_of_active_batches_per_listener: int = SENTINEL,
        max_queued_executions_per_node: int = SENTINEL,
        max_queued_forked_executions_per_node: int = SENTINEL,
        max_simultaneous_executions_per_node: int = SENTINEL,
        max_simultaneous_forked_executions_per_node: int = SENTINEL,
        max_simultaneous_forked_jvms_per_node: int = SENTINEL,
        max_size_for_update_operation: int = SENTINEL,
        milliseconds_logging: bool = SENTINEL,
        min_number_of_hosts_for_unicast_autodetect: int = SENTINEL,
        monitor_number_of_open_files: bool = SENTINEL,
        multicast_address: str = SENTINEL,
        multicast_port: int = SENTINEL,
        persisted_connector_cache: bool = SENTINEL,
        process_execution_directory_level: int = SENTINEL,
        processed_document_archive_directory: str = SENTINEL,
        proxy_user_id: str = SENTINEL,
        purge_manager: bool = SENTINEL,
        purge_manager_threads: int = SENTINEL,
        purge_schedule_for_components: str = SENTINEL,
        purge_schedule_for_logs: str = SENTINEL,
        purge_schedule_for_processed_documents: str = SENTINEL,
        purge_schedule_for_temporary_data: str = SENTINEL,
        rolling_restart_force_timeout: int = SENTINEL,
        rolling_restart_next_in_line_timeout: int = SENTINEL,
        runtime_data_directory_level: int = SENTINEL,
        runtime_pending_shutdown_delay: int = SENTINEL,
        save_swagger_template_in_work_folder: bool = SENTINEL,
        security_policy: SecurityPolicy = SENTINEL,
        sequential_processing_of_custom_script_engine_data: bool = SENTINEL,
        show_runtime_icon_in_system_tray: bool = SENTINEL,
        ssl_debug_logging: bool = SENTINEL,
        standard_error_log_level: StandardErrorLogLevel = SENTINEL,
        standard_output_and_error_logging: bool = SENTINEL,
        tcp_port_for_unicast: int = SENTINEL,
        threads_for_account_initialization: int = SENTINEL,
        threads_for_account_initialization_during_starting_and_stopping_plugins: int = SENTINEL,
        threads_for_recovering_executions_during_container_startup: int = SENTINEL,
        threads_for_runtime_scheduling: int = SENTINEL,
        threads_for_runtime_to_platform_messages: int = SENTINEL,
        threads_for_runtime_to_platform_polling: int = SENTINEL,
        threads_for_runtime_to_runtime_messages: int = SENTINEL,
        timeout_for_escalating_cluster_issue: int = SENTINEL,
        timeout_for_queued_executions_per_node: int = SENTINEL,
        timeout_for_queued_forked_executions_per_node: int = SENTINEL,
        trace_logging: bool = SENTINEL,
        use_local_storage_for_runtime_assets: bool = SENTINEL,
        worker_heartbeat_timeout: int = SENTINEL,
        working_data_local_storage_directory: str = SENTINEL,
        xml_entity_processing: bool = SENTINEL,
        xml_external_entity_processing: bool = SENTINEL,
        **kwargs,
    ):
        """StandardProperties - see class docstring for parameter details."""
        if account_working_data_directories is not SENTINEL:
            self.account_working_data_directories = account_working_data_directories
        if allow_browsing is not SENTINEL:
            self.allow_browsing = allow_browsing
        if allow_user_logs is not SENTINEL:
            self.allow_user_logs = allow_user_logs
        if archive_processed_documents is not SENTINEL:
            self.archive_processed_documents = archive_processed_documents
        if async_message_poller_timeout_for_cluster_scale_down is not SENTINEL:
            self.async_message_poller_timeout_for_cluster_scale_down = (
                async_message_poller_timeout_for_cluster_scale_down
            )
        if auto_restart_on_out_of_memory is not SENTINEL:
            self.auto_restart_on_out_of_memory = auto_restart_on_out_of_memory
        if auto_restart_on_too_many_files_error is not SENTINEL:
            self.auto_restart_on_too_many_files_error = (
                auto_restart_on_too_many_files_error
            )
        if aws_secrets_manager is not SENTINEL:
            self.aws_secrets_manager = aws_secrets_manager
        if aws_secrets_manager_region is not SENTINEL:
            self.aws_secrets_manager_region = aws_secrets_manager_region
        if azure_secrets_manager is not SENTINEL:
            self.azure_secrets_manager = azure_secrets_manager
        if clean_up_custom_script_engine_data_on_completion is not SENTINEL:
            self.clean_up_custom_script_engine_data_on_completion = (
                clean_up_custom_script_engine_data_on_completion
            )
        if cloud_partition_replicas is not SENTINEL:
            self.cloud_partition_replicas = cloud_partition_replicas
        if cloud_partition_size is not SENTINEL:
            self.cloud_partition_size = cloud_partition_size
        if cluster_bootstrap_timeout is not SENTINEL:
            self.cluster_bootstrap_timeout = cluster_bootstrap_timeout
        if cluster_network_bind_address is not SENTINEL:
            self.cluster_network_bind_address = cluster_network_bind_address
        if cluster_network_transport_type is not SENTINEL:
            self.cluster_network_transport_type = self._enum_matching(
                cluster_network_transport_type,
                ClusterNetworkTransportType.list(),
                "cluster_network_transport_type",
            )
        if cluster_problem_automatic_delete_delay is not SENTINEL:
            self.cluster_problem_automatic_delete_delay = (
                cluster_problem_automatic_delete_delay
            )
        if cluster_problem_automatic_shutdown_delay is not SENTINEL:
            self.cluster_problem_automatic_shutdown_delay = (
                cluster_problem_automatic_shutdown_delay
            )
        if cluster_rolling_restart_percentage is not SENTINEL:
            self.cluster_rolling_restart_percentage = cluster_rolling_restart_percentage
        if compress_history_after_x_days is not SENTINEL:
            self.compress_history_after_x_days = compress_history_after_x_days
        if connector_browsing_idle_timeout is not SENTINEL:
            self.connector_browsing_idle_timeout = connector_browsing_idle_timeout
        if connector_browsing_max_thread_count is not SENTINEL:
            self.connector_browsing_max_thread_count = (
                connector_browsing_max_thread_count
            )
        if connector_browsing_maximum_browse_time is not SENTINEL:
            self.connector_browsing_maximum_browse_time = (
                connector_browsing_maximum_browse_time
            )
        if connector_browsing_time_to_live is not SENTINEL:
            self.connector_browsing_time_to_live = connector_browsing_time_to_live
        if connector_server_startup_timeout is not SENTINEL:
            self.connector_server_startup_timeout = connector_server_startup_timeout
        if connector_trace_logging is not SENTINEL:
            self.connector_trace_logging = connector_trace_logging
        if container_force_restart is not SENTINEL:
            self.container_force_restart = container_force_restart
        if container_host_name is not SENTINEL:
            self.container_host_name = container_host_name
        if container_name is not SENTINEL:
            self.container_name = container_name
        if container_purge_days is not SENTINEL:
            self.container_purge_days = container_purge_days
        if container_purge_immediately is not SENTINEL:
            self.container_purge_immediately = container_purge_immediately
        if control_id_cache_idle_timeout is not SENTINEL:
            self.control_id_cache_idle_timeout = control_id_cache_idle_timeout
        if control_id_cache_time_to_live is not SENTINEL:
            self.control_id_cache_time_to_live = control_id_cache_time_to_live
        if counter_file_lock_retry is not SENTINEL:
            self.counter_file_lock_retry = counter_file_lock_retry
        if counter_lock_retry_maximum_retries is not SENTINEL:
            self.counter_lock_retry_maximum_retries = (
                counter_lock_retry_maximum_retries
            )
        if counter_lock_retry_wait_time is not SENTINEL:
            self.counter_lock_retry_wait_time = counter_lock_retry_wait_time
        if customized_procbrowser_script_file_name is not SENTINEL:
            self.customized_procbrowser_script_file_name = (
                customized_procbrowser_script_file_name
            )
        if customized_procrunner_script_file_name is not SENTINEL:
            self.customized_procrunner_script_file_name = (
                customized_procrunner_script_file_name
            )
        if customized_procworker_script_file_name is not SENTINEL:
            self.customized_procworker_script_file_name = (
                customized_procworker_script_file_name
            )
        if customized_restart_script_file_name is not SENTINEL:
            self.customized_restart_script_file_name = (
                customized_restart_script_file_name
            )
        if debug_log_level_threshold is not SENTINEL:
            self.debug_log_level_threshold = self._enum_matching(
                debug_log_level_threshold,
                DebugLogLevelThreshold.list(),
                "debug_log_level_threshold",
            )
        if debug_logging is not SENTINEL:
            self.debug_logging = debug_logging
        if decommission_time_for_post_pause_sleep is not SENTINEL:
            self.decommission_time_for_post_pause_sleep = (
                decommission_time_for_post_pause_sleep
            )
        if default_time_zone_for_account_schedules is not SENTINEL:
            self.default_time_zone_for_account_schedules = (
                default_time_zone_for_account_schedules
            )
        if disk_space_monitoring is not SENTINEL:
            self.disk_space_monitoring = disk_space_monitoring
        if disk_space_monitoring_account_auto_suspension is not SENTINEL:
            self.disk_space_monitoring_account_auto_suspension = (
                disk_space_monitoring_account_auto_suspension
            )
        if disk_space_monitoring_frequency is not SENTINEL:
            self.disk_space_monitoring_frequency = disk_space_monitoring_frequency
        if disk_space_monitoring_threads is not SENTINEL:
            self.disk_space_monitoring_threads = disk_space_monitoring_threads
        if disk_space_monitoring_verbose_logging is not SENTINEL:
            self.disk_space_monitoring_verbose_logging = (
                disk_space_monitoring_verbose_logging
            )
        if disk_space_warning_limit is not SENTINEL:
            self.disk_space_warning_limit = disk_space_warning_limit
        if dump_to_file_when_exceeding_open_file_threshold is not SENTINEL:
            self.dump_to_file_when_exceeding_open_file_threshold = (
                dump_to_file_when_exceeding_open_file_threshold
            )
        if early_stale_execution_worker_ttl_percentage is not SENTINEL:
            self.early_stale_execution_worker_ttl_percentage = (
                early_stale_execution_worker_ttl_percentage
            )
        if elastic_worker_directory_level is not SENTINEL:
            self.elastic_worker_directory_level = elastic_worker_directory_level
        if elastic_worker_metrics_polling_period is not SENTINEL:
            self.elastic_worker_metrics_polling_period = (
                elastic_worker_metrics_polling_period
            )
        if execute_processes_as_forked_jvms is not SENTINEL:
            self.execute_processes_as_forked_jvms = self._enum_matching(
                execute_processes_as_forked_jvms,
                ExecuteProcessesAsForkedJvms.list(),
                "execute_processes_as_forked_jvms",
            )
        if execution_worker_idle_timeout is not SENTINEL:
            self.execution_worker_idle_timeout = execution_worker_idle_timeout
        if execution_worker_local_port_range is not SENTINEL:
            self.execution_worker_local_port_range = execution_worker_local_port_range
        if execution_worker_pending_updates_queue_size is not SENTINEL:
            self.execution_worker_pending_updates_queue_size = (
                execution_worker_pending_updates_queue_size
            )
        if execution_worker_startup_timeout is not SENTINEL:
            self.execution_worker_startup_timeout = execution_worker_startup_timeout
        if execution_worker_thread_pool_idle_timeout is not SENTINEL:
            self.execution_worker_thread_pool_idle_timeout = (
                execution_worker_thread_pool_idle_timeout
            )
        if execution_worker_time_to_live is not SENTINEL:
            self.execution_worker_time_to_live = execution_worker_time_to_live
        if execution_workers_enabled is not SENTINEL:
            self.execution_workers_enabled = execution_workers_enabled
        if external_hostname is not SENTINEL:
            self.external_hostname = external_hostname
        if force_restart_override_for_cluster_scale_down is not SENTINEL:
            self.force_restart_override_for_cluster_scale_down = (
                force_restart_override_for_cluster_scale_down
            )
        if force_start_shared_web_server is not SENTINEL:
            self.force_start_shared_web_server = force_start_shared_web_server
        if generate_heap_dump_on_low_memory is not SENTINEL:
            self.generate_heap_dump_on_low_memory = generate_heap_dump_on_low_memory
        if https_protocols is not SENTINEL:
            self.https_protocols = https_protocols
        if initial_hosts_for_unicast is not SENTINEL:
            self.initial_hosts_for_unicast = initial_hosts_for_unicast
        if jgroups_debug_logging is not SENTINEL:
            self.jgroups_debug_logging = jgroups_debug_logging
        if listener_startup_mode is not SENTINEL:
            self.listener_startup_mode = self._enum_matching(
                listener_startup_mode,
                ListenerStartupMode.list(),
                "listener_startup_mode",
            )
        if logger_queue_size is not SENTINEL:
            self.logger_queue_size = logger_queue_size
        if logger_timeout is not SENTINEL:
            self.logger_timeout = logger_timeout
        if low_latency_warning_threshold is not SENTINEL:
            self.low_latency_warning_threshold = low_latency_warning_threshold
        if low_memory_mode_threshold is not SENTINEL:
            self.low_memory_mode_threshold = low_memory_mode_threshold
        if low_remaining_open_files_threshold is not SENTINEL:
            self.low_remaining_open_files_threshold = (
                low_remaining_open_files_threshold
            )
        if mapping_expand_child_elements_legacy is not SENTINEL:
            self.mapping_expand_child_elements_legacy = (
                mapping_expand_child_elements_legacy
            )
        if max_cached_control_ids is not SENTINEL:
            self.max_cached_control_ids = max_cached_control_ids
        if max_cached_transaction_keys is not SENTINEL:
            self.max_cached_transaction_keys = max_cached_transaction_keys
        if max_document_elements_cache_size is not SENTINEL:
            self.max_document_elements_cache_size = max_document_elements_cache_size
        if max_execution_threads_per_connector_browser is not SENTINEL:
            self.max_execution_threads_per_connector_browser = (
                max_execution_threads_per_connector_browser
            )
        if max_execution_threads_per_execution_worker is not SENTINEL:
            self.max_execution_threads_per_execution_worker = (
                max_execution_threads_per_execution_worker
            )
        if max_execution_threads_per_forked_execution is not SENTINEL:
            self.max_execution_threads_per_forked_execution = (
                max_execution_threads_per_forked_execution
            )
        if max_flow_control_units is not SENTINEL:
            self.max_flow_control_units = max_flow_control_units
        if max_forked_execution_time_in_cloud is not SENTINEL:
            self.max_forked_execution_time_in_cloud = (
                max_forked_execution_time_in_cloud
            )
        if max_number_of_active_batches_per_listener is not SENTINEL:
            self.max_number_of_active_batches_per_listener = (
                max_number_of_active_batches_per_listener
            )
        if max_queued_executions_per_node is not SENTINEL:
            self.max_queued_executions_per_node = max_queued_executions_per_node
        if max_queued_forked_executions_per_node is not SENTINEL:
            self.max_queued_forked_executions_per_node = (
                max_queued_forked_executions_per_node
            )
        if max_simultaneous_executions_per_node is not SENTINEL:
            self.max_simultaneous_executions_per_node = (
                max_simultaneous_executions_per_node
            )
        if max_simultaneous_forked_executions_per_node is not SENTINEL:
            self.max_simultaneous_forked_executions_per_node = (
                max_simultaneous_forked_executions_per_node
            )
        if max_simultaneous_forked_jvms_per_node is not SENTINEL:
            self.max_simultaneous_forked_jvms_per_node = (
                max_simultaneous_forked_jvms_per_node
            )
        if max_size_for_update_operation is not SENTINEL:
            self.max_size_for_update_operation = max_size_for_update_operation
        if milliseconds_logging is not SENTINEL:
            self.milliseconds_logging = milliseconds_logging
        if min_number_of_hosts_for_unicast_autodetect is not SENTINEL:
            self.min_number_of_hosts_for_unicast_autodetect = (
                min_number_of_hosts_for_unicast_autodetect
            )
        if monitor_number_of_open_files is not SENTINEL:
            self.monitor_number_of_open_files = monitor_number_of_open_files
        if multicast_address is not SENTINEL:
            self.multicast_address = multicast_address
        if multicast_port is not SENTINEL:
            self.multicast_port = multicast_port
        if persisted_connector_cache is not SENTINEL:
            self.persisted_connector_cache = persisted_connector_cache
        if process_execution_directory_level is not SENTINEL:
            self.process_execution_directory_level = process_execution_directory_level
        if processed_document_archive_directory is not SENTINEL:
            self.processed_document_archive_directory = (
                processed_document_archive_directory
            )
        if proxy_user_id is not SENTINEL:
            self.proxy_user_id = proxy_user_id
        if purge_manager is not SENTINEL:
            self.purge_manager = purge_manager
        if purge_manager_threads is not SENTINEL:
            self.purge_manager_threads = purge_manager_threads
        if purge_schedule_for_components is not SENTINEL:
            self.purge_schedule_for_components = purge_schedule_for_components
        if purge_schedule_for_logs is not SENTINEL:
            self.purge_schedule_for_logs = purge_schedule_for_logs
        if purge_schedule_for_processed_documents is not SENTINEL:
            self.purge_schedule_for_processed_documents = (
                purge_schedule_for_processed_documents
            )
        if purge_schedule_for_temporary_data is not SENTINEL:
            self.purge_schedule_for_temporary_data = purge_schedule_for_temporary_data
        if rolling_restart_force_timeout is not SENTINEL:
            self.rolling_restart_force_timeout = rolling_restart_force_timeout
        if rolling_restart_next_in_line_timeout is not SENTINEL:
            self.rolling_restart_next_in_line_timeout = (
                rolling_restart_next_in_line_timeout
            )
        if runtime_data_directory_level is not SENTINEL:
            self.runtime_data_directory_level = runtime_data_directory_level
        if runtime_pending_shutdown_delay is not SENTINEL:
            self.runtime_pending_shutdown_delay = runtime_pending_shutdown_delay
        if save_swagger_template_in_work_folder is not SENTINEL:
            self.save_swagger_template_in_work_folder = (
                save_swagger_template_in_work_folder
            )
        if security_policy is not SENTINEL:
            self.security_policy = self._enum_matching(
                security_policy, SecurityPolicy.list(), "security_policy"
            )
        if sequential_processing_of_custom_script_engine_data is not SENTINEL:
            self.sequential_processing_of_custom_script_engine_data = (
                sequential_processing_of_custom_script_engine_data
            )
        if show_runtime_icon_in_system_tray is not SENTINEL:
            self.show_runtime_icon_in_system_tray = show_runtime_icon_in_system_tray
        if ssl_debug_logging is not SENTINEL:
            self.ssl_debug_logging = ssl_debug_logging
        if standard_error_log_level is not SENTINEL:
            self.standard_error_log_level = self._enum_matching(
                standard_error_log_level,
                StandardErrorLogLevel.list(),
                "standard_error_log_level",
            )
        if standard_output_and_error_logging is not SENTINEL:
            self.standard_output_and_error_logging = standard_output_and_error_logging
        if tcp_port_for_unicast is not SENTINEL:
            self.tcp_port_for_unicast = tcp_port_for_unicast
        if threads_for_account_initialization is not SENTINEL:
            self.threads_for_account_initialization = (
                threads_for_account_initialization
            )
        if threads_for_account_initialization_during_starting_and_stopping_plugins is not SENTINEL:
            self.threads_for_account_initialization_during_starting_and_stopping_plugins = (
                threads_for_account_initialization_during_starting_and_stopping_plugins
            )
        if threads_for_recovering_executions_during_container_startup is not SENTINEL:
            self.threads_for_recovering_executions_during_container_startup = (
                threads_for_recovering_executions_during_container_startup
            )
        if threads_for_runtime_scheduling is not SENTINEL:
            self.threads_for_runtime_scheduling = threads_for_runtime_scheduling
        if threads_for_runtime_to_platform_messages is not SENTINEL:
            self.threads_for_runtime_to_platform_messages = (
                threads_for_runtime_to_platform_messages
            )
        if threads_for_runtime_to_platform_polling is not SENTINEL:
            self.threads_for_runtime_to_platform_polling = (
                threads_for_runtime_to_platform_polling
            )
        if threads_for_runtime_to_runtime_messages is not SENTINEL:
            self.threads_for_runtime_to_runtime_messages = (
                threads_for_runtime_to_runtime_messages
            )
        if timeout_for_escalating_cluster_issue is not SENTINEL:
            self.timeout_for_escalating_cluster_issue = (
                timeout_for_escalating_cluster_issue
            )
        if timeout_for_queued_executions_per_node is not SENTINEL:
            self.timeout_for_queued_executions_per_node = (
                timeout_for_queued_executions_per_node
            )
        if timeout_for_queued_forked_executions_per_node is not SENTINEL:
            self.timeout_for_queued_forked_executions_per_node = (
                timeout_for_queued_forked_executions_per_node
            )
        if trace_logging is not SENTINEL:
            self.trace_logging = trace_logging
        if use_local_storage_for_runtime_assets is not SENTINEL:
            self.use_local_storage_for_runtime_assets = (
                use_local_storage_for_runtime_assets
            )
        if worker_heartbeat_timeout is not SENTINEL:
            self.worker_heartbeat_timeout = worker_heartbeat_timeout
        if working_data_local_storage_directory is not SENTINEL:
            self.working_data_local_storage_directory = (
                working_data_local_storage_directory
            )
        if xml_entity_processing is not SENTINEL:
            self.xml_entity_processing = xml_entity_processing
        if xml_external_entity_processing is not SENTINEL:
            self.xml_external_entity_processing = xml_external_entity_processing
        self._kwargs = kwargs




from enum import Enum
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL


class RosettaNetConnectorRecordSimpleExpressionOperator(Enum):
    """An enumeration representing different categories.

    :cvar EQUALS: "EQUALS"
    :vartype EQUALS: str
    :cvar STARTSWITH: "STARTS_WITH"
    :vartype STARTSWITH: str
    :cvar BETWEEN: "BETWEEN"
    :vartype BETWEEN: str
    :cvar GREATERTHAN: "GREATER_THAN"
    :vartype GREATERTHAN: str
    :cvar GREATERTHANOREQUAL: "GREATER_THAN_OR_EQUAL"
    :vartype GREATERTHANOREQUAL: str
    :cvar LESSTHAN: "LESS_THAN"
    :vartype LESSTHAN: str
    :cvar LESSTHANOREQUAL: "LESS_THAN_OR_EQUAL"
    :vartype LESSTHANOREQUAL: str
    """

    EQUALS = "EQUALS"
    STARTSWITH = "STARTS_WITH"
    BETWEEN = "BETWEEN"
    GREATERTHAN = "GREATER_THAN"
    GREATERTHANOREQUAL = "GREATER_THAN_OR_EQUAL"
    LESSTHAN = "LESS_THAN"
    LESSTHANOREQUAL = "LESS_THAN_OR_EQUAL"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                RosettaNetConnectorRecordSimpleExpressionOperator._member_map_.values(),
            )
        )


class RosettaNetConnectorRecordSimpleExpressionProperty(Enum):
    """An enumeration representing different categories.

    :cvar EXECUTIONID: "executionId"
    :vartype EXECUTIONID: str
    :cvar ATOMID: "atomId"
    :vartype ATOMID: str
    :cvar DATEPROCESSED: "dateProcessed"
    :vartype DATEPROCESSED: str
    :cvar ID: "id"
    :vartype ID: str
    :cvar ACTIONTYPE: "actionType"
    :vartype ACTIONTYPE: str
    :cvar CONNECTORTYPE: "connectorType"
    :vartype CONNECTORTYPE: str
    :cvar CONNECTORNAME: "connectorName"
    :vartype CONNECTORNAME: str
    :cvar OPERATIONNAME: "operationName"
    :vartype OPERATIONNAME: str
    :cvar DOCUMENTINDEX: "documentIndex"
    :vartype DOCUMENTINDEX: str
    :cvar SUCCESSFUL: "successful"
    :vartype SUCCESSFUL: str
    :cvar SIZE: "size"
    :vartype SIZE: str
    :cvar ERRORMESSAGE: "errorMessage"
    :vartype ERRORMESSAGE: str
    :cvar ACKSTATUS: "ackStatus"
    :vartype ACKSTATUS: str
    :cvar ACKREPORT: "ackReport"
    :vartype ACKREPORT: str
    :cvar SENDERID: "senderID"
    :vartype SENDERID: str
    :cvar RECEIVERID: "receiverID"
    :vartype RECEIVERID: str
    :cvar KNOWNINITIATINGPARTNERID: "knownInitiatingPartnerID"
    :vartype KNOWNINITIATINGPARTNERID: str
    :cvar FRAMEWORKVERSION: "frameworkVersion"
    :vartype FRAMEWORKVERSION: str
    :cvar PIPCODE: "PIPCode"
    :vartype PIPCODE: str
    :cvar PIPVERSION: "PIPVersion"
    :vartype PIPVERSION: str
    :cvar GLOBALPROCESSCODE: "globalProcessCode"
    :vartype GLOBALPROCESSCODE: str
    :cvar GLOBALBUSINESSACTIONCODE: "globalBusinessActionCode"
    :vartype GLOBALBUSINESSACTIONCODE: str
    :cvar GLOBALDOCUMENTFUNCTIONCODE: "globalDocumentFunctionCode"
    :vartype GLOBALDOCUMENTFUNCTIONCODE: str
    :cvar FROMGLOBALPARTNERROLECLASSIFICATIONCODE: "fromGlobalPartnerRoleClassificationCode"
    :vartype FROMGLOBALPARTNERROLECLASSIFICATIONCODE: str
    :cvar TOGLOBALPARTNERROLECLASSIFICATIONCODE: "toGlobalPartnerRoleClassificationCode"
    :vartype TOGLOBALPARTNERROLECLASSIFICATIONCODE: str
    :cvar FROMGLOBALBUSINESSSERVICECODE: "fromGlobalBusinessServiceCode"
    :vartype FROMGLOBALBUSINESSSERVICECODE: str
    :cvar TOGLOBALBUSINESSSERVICECODE: "toGlobalBusinessServiceCode"
    :vartype TOGLOBALBUSINESSSERVICECODE: str
    :cvar BUSINESSACTIVITYIDENTIFIER: "businessActivityIdentifier"
    :vartype BUSINESSACTIVITYIDENTIFIER: str
    :cvar PROCESSINSTANCEIDENTIFIER: "processInstanceIdentifier"
    :vartype PROCESSINSTANCEIDENTIFIER: str
    :cvar TRANSACTIONINSTANCEIDENTIFIER: "transactionInstanceIdentifier"
    :vartype TRANSACTIONINSTANCEIDENTIFIER: str
    :cvar ACTIONINSTANCEIDENTIFIER: "actionInstanceIdentifier"
    :vartype ACTIONINSTANCEIDENTIFIER: str
    :cvar INRESPONSETOGLOBALBUSINESSACTIONCODE: "inResponseToGlobalBusinessActionCode"
    :vartype INRESPONSETOGLOBALBUSINESSACTIONCODE: str
    :cvar INRESPONSETOINSTANCEIDENTIFIER: "inResponseToInstanceIdentifier"
    :vartype INRESPONSETOINSTANCEIDENTIFIER: str
    :cvar GLOBALUSAGECODE: "globalUsageCode"
    :vartype GLOBALUSAGECODE: str
    :cvar ATTEMPTCOUNT: "attemptCount"
    :vartype ATTEMPTCOUNT: str
    :cvar DATETIME: "dateTime"
    :vartype DATETIME: str
    :cvar ISSECURETRANSPORTREQUIRED: "isSecureTransportRequired"
    :vartype ISSECURETRANSPORTREQUIRED: str
    :cvar TIMETOACKNOWLEDGEACCEPTANCE: "timeToAcknowledgeAcceptance"
    :vartype TIMETOACKNOWLEDGEACCEPTANCE: str
    :cvar TIMETOACKNOWLEDGERECEIPT: "timeToAcknowledgeReceipt"
    :vartype TIMETOACKNOWLEDGERECEIPT: str
    :cvar TIMETOPERFORM: "timeToPerform"
    :vartype TIMETOPERFORM: str
    :cvar OUTBOUNDVALIDATIONSTATUS: "outboundValidationStatus"
    :vartype OUTBOUNDVALIDATIONSTATUS: str
    :cvar OUTBOUNDVALIDATIONREPORT: "outboundValidationReport"
    :vartype OUTBOUNDVALIDATIONREPORT: str
    """

    EXECUTIONID = "executionId"
    ATOMID = "atomId"
    DATEPROCESSED = "dateProcessed"
    ID = "id"
    ACTIONTYPE = "actionType"
    CONNECTORTYPE = "connectorType"
    CONNECTORNAME = "connectorName"
    OPERATIONNAME = "operationName"
    DOCUMENTINDEX = "documentIndex"
    SUCCESSFUL = "successful"
    SIZE = "size"
    ERRORMESSAGE = "errorMessage"
    ACKSTATUS = "ackStatus"
    ACKREPORT = "ackReport"
    SENDERID = "senderID"
    RECEIVERID = "receiverID"
    KNOWNINITIATINGPARTNERID = "knownInitiatingPartnerID"
    FRAMEWORKVERSION = "frameworkVersion"
    PIPCODE = "PIPCode"
    PIPVERSION = "PIPVersion"
    GLOBALPROCESSCODE = "globalProcessCode"
    GLOBALBUSINESSACTIONCODE = "globalBusinessActionCode"
    GLOBALDOCUMENTFUNCTIONCODE = "globalDocumentFunctionCode"
    FROMGLOBALPARTNERROLECLASSIFICATIONCODE = "fromGlobalPartnerRoleClassificationCode"
    TOGLOBALPARTNERROLECLASSIFICATIONCODE = "toGlobalPartnerRoleClassificationCode"
    FROMGLOBALBUSINESSSERVICECODE = "fromGlobalBusinessServiceCode"
    TOGLOBALBUSINESSSERVICECODE = "toGlobalBusinessServiceCode"
    BUSINESSACTIVITYIDENTIFIER = "businessActivityIdentifier"
    PROCESSINSTANCEIDENTIFIER = "processInstanceIdentifier"
    TRANSACTIONINSTANCEIDENTIFIER = "transactionInstanceIdentifier"
    ACTIONINSTANCEIDENTIFIER = "actionInstanceIdentifier"
    INRESPONSETOGLOBALBUSINESSACTIONCODE = "inResponseToGlobalBusinessActionCode"
    INRESPONSETOINSTANCEIDENTIFIER = "inResponseToInstanceIdentifier"
    GLOBALUSAGECODE = "globalUsageCode"
    ATTEMPTCOUNT = "attemptCount"
    DATETIME = "dateTime"
    ISSECURETRANSPORTREQUIRED = "isSecureTransportRequired"
    TIMETOACKNOWLEDGEACCEPTANCE = "timeToAcknowledgeAcceptance"
    TIMETOACKNOWLEDGERECEIPT = "timeToAcknowledgeReceipt"
    TIMETOPERFORM = "timeToPerform"
    OUTBOUNDVALIDATIONSTATUS = "outboundValidationStatus"
    OUTBOUNDVALIDATIONREPORT = "outboundValidationReport"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(
            map(
                lambda x: x.value,
                RosettaNetConnectorRecordSimpleExpressionProperty._member_map_.values(),
            )
        )


@JsonMap({})
class RosettaNetConnectorRecordSimpleExpression(BaseModel):
    """RosettaNetConnectorRecordSimpleExpression

    :param argument: argument, defaults to None
    :type argument: List[str], optional
    :param operator: operator
    :type operator: RosettaNetConnectorRecordSimpleExpressionOperator
    :param property: property
    :type property: RosettaNetConnectorRecordSimpleExpressionProperty
    """

    def __init__(
        self,
        operator: RosettaNetConnectorRecordSimpleExpressionOperator,
        property: RosettaNetConnectorRecordSimpleExpressionProperty,
        argument: List[str] = SENTINEL,
        **kwargs
    ):
        """RosettaNetConnectorRecordSimpleExpression

        :param argument: argument, defaults to None
        :type argument: List[str], optional
        :param operator: operator
        :type operator: RosettaNetConnectorRecordSimpleExpressionOperator
        :param property: property
        :type property: RosettaNetConnectorRecordSimpleExpressionProperty
        """
        if argument is not SENTINEL:
            self.argument = argument
        self.operator = self._enum_matching(
            operator,
            RosettaNetConnectorRecordSimpleExpressionOperator.list(),
            "operator",
        )
        self.property = self._enum_matching(
            property,
            RosettaNetConnectorRecordSimpleExpressionProperty.list(),
            "property",
        )
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..audit_log import AuditLogService
from ...models import (
    AuditLog,
    AuditLogBulkResponse,
    AuditLogBulkRequest,
    AuditLogQueryResponse,
    AuditLogQueryConfig,
)


class AuditLogServiceAsync(AuditLogService):
    """
    Async Wrapper for AuditLogServiceAsync
    """

    def get_audit_log(self, id_: str) -> Awaitable[Union[AuditLog, str]]:
        return to_async(super().get_audit_log)(id_)

    def bulk_audit_log(
        self, request_body: AuditLogBulkRequest = None
    ) -> Awaitable[Union[AuditLogBulkResponse, str]]:
        return to_async(super().bulk_audit_log)(request_body)

    def query_audit_log(
        self, request_body: AuditLogQueryConfig = None
    ) -> Awaitable[Union[AuditLogQueryResponse, str]]:
        return to_async(super().query_audit_log)(request_body)

    def query_more_audit_log(
        self, request_body: str
    ) -> Awaitable[Union[AuditLogQueryResponse, str]]:
        return to_async(super().query_more_audit_log)(request_body)




from __future__ import annotations
from typing import List
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .component_merge_config import ComponentMergeConfig


@JsonMap({"component_merge_config": "ComponentMergeConfig"})
class ComponentMergeConfigs(BaseModel):
    """ComponentMergeConfigs

    :param component_merge_config: A list of ComponentMergeConfig entries., defaults to None
    :type component_merge_config: List[ComponentMergeConfig], optional
    """

    def __init__(
        self,
        component_merge_config: List[ComponentMergeConfig] = SENTINEL,
        **kwargs,
    ):
        """ComponentMergeConfigs

        :param component_merge_config: A list of ComponentMergeConfig entries., defaults to None
        :type component_merge_config: List[ComponentMergeConfig], optional
        """
        if component_merge_config is not SENTINEL:
            self.component_merge_config = self._define_list(
                component_merge_config, ComponentMergeConfig
            )
        self._kwargs = kwargs




from __future__ import annotations
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .field_summary import FieldSummary


@JsonMap(
    {
        "connection_id": "connectionId",
        "environment_id": "environmentId",
        "extension_group_id": "extensionGroupId",
        "id_": "id",
        "process_id": "processId",
    }
)
class EnvironmentConnectionFieldExtensionSummary(BaseModel):
    """EnvironmentConnectionFieldExtensionSummary

    :param connection_id: connection_id, defaults to None
    :type connection_id: str, optional
    :param environment_id: environment_id, defaults to None
    :type environment_id: str, optional
    :param extension_group_id: extension_group_id, defaults to None
    :type extension_group_id: str, optional
    :param field: field
    :type field: FieldSummary
    :param id_: id_, defaults to None
    :type id_: str, optional
    :param process_id: process_id, defaults to None
    :type process_id: str, optional
    """

    def __init__(
        self,
        field: FieldSummary,
        connection_id: str = SENTINEL,
        environment_id: str = SENTINEL,
        extension_group_id: str = SENTINEL,
        id_: str = SENTINEL,
        process_id: str = SENTINEL,
        **kwargs,
    ):
        """EnvironmentConnectionFieldExtensionSummary

        :param connection_id: connection_id, defaults to None
        :type connection_id: str, optional
        :param environment_id: environment_id, defaults to None
        :type environment_id: str, optional
        :param extension_group_id: extension_group_id, defaults to None
        :type extension_group_id: str, optional
        :param field: field
        :type field: FieldSummary
        :param id_: id_, defaults to None
        :type id_: str, optional
        :param process_id: process_id, defaults to None
        :type process_id: str, optional
        """
        if connection_id is not SENTINEL:
            self.connection_id = connection_id
        if environment_id is not SENTINEL:
            self.environment_id = environment_id
        if extension_group_id is not SENTINEL:
            self.extension_group_id = extension_group_id
        self.field = self._define_object(field, FieldSummary)
        if id_ is not SENTINEL:
            self.id_ = id_
        if process_id is not SENTINEL:
            self.process_id = process_id
        self._kwargs = kwargs




from typing import Awaitable, Union
from .utils.to_async import to_async
from ..document_count_account import DocumentCountAccountService
from ...models import DocumentCountAccountQueryResponse, DocumentCountAccountQueryConfig


class DocumentCountAccountServiceAsync(DocumentCountAccountService):
    """
    Async Wrapper for DocumentCountAccountServiceAsync
    """

    def query_document_count_account(
        self, request_body: DocumentCountAccountQueryConfig = None
    ) -> Awaitable[Union[DocumentCountAccountQueryResponse, str]]:
        return to_async(super().query_document_count_account)(request_body)

    def query_more_document_count_account(
        self, request_body: str
    ) -> Awaitable[Union[DocumentCountAccountQueryResponse, str]]:
        return to_async(super().query_more_document_count_account)(request_body)




from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .cloud_simple_expression import CloudSimpleExpression
from .cloud_grouping_expression import CloudGroupingExpression


class CloudExpressionGuard(OneOfBaseModel):
    class_list = {
        "CloudSimpleExpression": CloudSimpleExpression,
        "CloudGroupingExpression": CloudGroupingExpression,
    }


CloudExpression = Union[CloudSimpleExpression, CloudGroupingExpression]




from __future__ import annotations
from enum import Enum
from .utils.json_map import JsonMap
from .utils.base_model import BaseModel
from .utils.sentinel import SENTINEL
from .merge_request_details import MergeRequestDetails


class MergeRequestAction(Enum):
    """An enumeration representing different categories.

    :cvar UPDATE: "UPDATE"
    :vartype UPDATE: str
    :cvar MERGE: "MERGE"
    :vartype MERGE: str
    :cvar RETRYDRAFTING: "RETRY_DRAFTING"
    :vartype RETRYDRAFTING: str
    :cvar REVERT: "REVERT"
    :vartype REVERT: str
    """

    UPDATE = "UPDATE"
    MERGE = "MERGE"
    RETRYDRAFTING = "RETRY_DRAFTING"
    REVERT = "REVERT"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, MergeRequestAction._member_map_.values()))


class PreviousStage(Enum):
    """An enumeration representing different categories.

    :cvar NOTEXIST: "NOT_EXIST"
    :vartype NOTEXIST: str
    :cvar DRAFTING: "DRAFTING"
    :vartype DRAFTING: str
    :cvar FAILEDTODRAFT: "FAILED_TO_DRAFT"
    :vartype FAILEDTODRAFT: str
    :cvar FAILEDTOREDRAFT: "FAILED_TO_REDRAFT"
    :vartype FAILEDTOREDRAFT: str
    :cvar DRAFTED: "DRAFTED"
    :vartype DRAFTED: str
    :cvar REVIEWING: "REVIEWING"
    :vartype REVIEWING: str
    :cvar MERGING: "MERGING"
    :vartype MERGING: str
    :cvar MERGED: "MERGED"
    :vartype MERGED: str
    :cvar FAILEDTOMERGE: "FAILED_TO_MERGE"
    :vartype FAILEDTOMERGE: str
    :cvar DELETED: "DELETED"
    :vartype DELETED: str
    :cvar REDRAFTING: "REDRAFTING"
    :vartype REDRAFTING: str
    :cvar REVERTED: "REVERTED"
    :vartype REVERTED: str
    """

    NOTEXIST = "NOT_EXIST"
    DRAFTING = "DRAFTING"
    FAILEDTODRAFT = "FAILED_TO_DRAFT"
    FAILEDTOREDRAFT = "FAILED_TO_REDRAFT"
    DRAFTED = "DRAFTED"
    REVIEWING = "REVIEWING"
    MERGING = "MERGING"
    MERGED = "MERGED"
    FAILEDTOMERGE = "FAILED_TO_MERGE"
    DELETED = "DELETED"
    REDRAFTING = "REDRAFTING"
    REVERTED = "REVERTED"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, PreviousStage._member_map_.values()))


class PriorityBranch(Enum):
    """An enumeration representing different categories.

    :cvar SOURCE: "SOURCE"
    :vartype SOURCE: str
    :cvar DESTINATION: "DESTINATION"
    :vartype DESTINATION: str
    """

    SOURCE = "SOURCE"
    DESTINATION = "DESTINATION"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, PriorityBranch._member_map_.values()))


class MergeRequestStage(Enum):
    """An enumeration representing different categories.

    :cvar NOTEXIST: "NOT_EXIST"
    :vartype NOTEXIST: str
    :cvar DRAFTING: "DRAFTING"
    :vartype DRAFTING: str
    :cvar FAILEDTODRAFT: "FAILED_TO_DRAFT"
    :vartype FAILEDTODRAFT: str
    :cvar FAILEDTOREDRAFT: "FAILED_TO_REDRAFT"
    :vartype FAILEDTOREDRAFT: str
    :cvar DRAFTED: "DRAFTED"
    :vartype DRAFTED: str
    :cvar REVIEWING: "REVIEWING"
    :vartype REVIEWING: str
    :cvar MERGING: "MERGING"
    :vartype MERGING: str
    :cvar MERGED: "MERGED"
    :vartype MERGED: str
    :cvar FAILEDTOMERGE: "FAILED_TO_MERGE"
    :vartype FAILEDTOMERGE: str
    :cvar DELETED: "DELETED"
    :vartype DELETED: str
    :cvar REDRAFTING: "REDRAFTING"
    :vartype REDRAFTING: str
    :cvar REVERTED: "REVERTED"
    :vartype REVERTED: str
    """

    NOTEXIST = "NOT_EXIST"
    DRAFTING = "DRAFTING"
    FAILEDTODRAFT = "FAILED_TO_DRAFT"
    FAILEDTOREDRAFT = "FAILED_TO_REDRAFT"
    DRAFTED = "DRAFTED"
    REVIEWING = "REVIEWING"
    MERGING = "MERGING"
    MERGED = "MERGED"
    FAILEDTOMERGE = "FAILED_TO_MERGE"
    DELETED = "DELETED"
    REDRAFTING = "REDRAFTING"
    REVERTED = "REVERTED"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, MergeRequestStage._member_map_.values()))


class Strategy(Enum):
    """An enumeration representing different categories.

    :cvar OVERRIDE: "OVERRIDE"
    :vartype OVERRIDE: str
    :cvar CONFLICTRESOLVE: "CONFLICT_RESOLVE"
    :vartype CONFLICTRESOLVE: str
    :cvar SUBSET: "SUBSET"
    :vartype SUBSET: str
    """

    OVERRIDE = "OVERRIDE"
    CONFLICTRESOLVE = "CONFLICT_RESOLVE"
    SUBSET = "SUBSET"

    def list():
        """Lists all category values.

        :return: A list of all category values.
        :rtype: list
        """
        return list(map(lambda x: x.value, Strategy._member_map_.values()))


@JsonMap(
    {
        "merge_request_details": "MergeRequestDetails",
        "created_by": "createdBy",
        "created_date": "createdDate",
        "destination_branch_id": "destinationBranchId",
        "destination_branch_name": "destinationBranchName",
        "id_": "id",
        "inactive_date": "inactiveDate",
        "lock_nonce": "lockNonce",
        "locked_by": "lockedBy",
        "locked_date": "lockedDate",
        "merge_request_action": "mergeRequestAction",
        "modified_by": "modifiedBy",
        "modified_date": "modifiedDate",
        "previous_stage": "previousStage",
        "priority_branch": "priorityBranch",
        "source_branch_id": "sourceBranchId",
        "source_branch_name": "sourceBranchName",
    }
)
class MergeRequest(BaseModel):
    """MergeRequest

    :param merge_request_details: merge_request_details
    :type merge_request_details: MergeRequestDetails
    :param created_by: The user who created the merge request., defaults to None
    :type created_by: str, optional
    :param created_date: The date and time the merge request was created., defaults to None
    :type created_date: str, optional
    :param destination_branch_id: The ID of the destination branch., defaults to None
    :type destination_branch_id: str, optional
    :param destination_branch_name: destination_branch_name, defaults to None
    :type destination_branch_name: str, optional
    :param id_: id_, defaults to None
    :type id_: str, optional
    :param inactive_date: inactive_date, defaults to None
    :type inactive_date: str, optional
    :param lock_nonce: lock_nonce, defaults to None
    :type lock_nonce: int, optional
    :param locked_by: locked_by, defaults to None
    :type locked_by: str, optional
    :param locked_date: locked_date, defaults to None
    :type locked_date: str, optional
    :param merge_request_action: merge_request_action, defaults to None
    :type merge_request_action: MergeRequestAction, optional
    :param modified_by: The user who last modified the merge request., defaults to None
    :type modified_by: str, optional
    :param modified_date: The date and time the merge request was last modified., defaults to None
    :type modified_date: str, optional
    :param note: note, defaults to None
    :type note: str, optional
    :param previous_stage: The previous stage of the merge., defaults to None
    :type previous_stage: PreviousStage, optional
    :param priority_branch: The branch which should take priority in an override merge., defaults to None
    :type priority_branch: PriorityBranch, optional
    :param source_branch_id: The ID of the source branch., defaults to None
    :type source_branch_id: str, optional
    :param source_branch_name: source_branch_name, defaults to None
    :type source_branch_name: str, optional
    :param stage: The current stage of the merge., defaults to None
    :type stage: MergeRequestStage, optional
    :param strategy: The merge strategy., defaults to None
    :type strategy: Strategy, optional
    """

    def __init__(
        self,
        merge_request_details: MergeRequestDetails,
        created_by: str = SENTINEL,
        created_date: str = SENTINEL,
        destination_branch_id: str = SENTINEL,
        destination_branch_name: str = SENTINEL,
        id_: str = SENTINEL,
        inactive_date: str = SENTINEL,
        lock_nonce: int = SENTINEL,
        locked_by: str = SENTINEL,
        locked_date: str = SENTINEL,
        merge_request_action: MergeRequestAction = SENTINEL,
        modified_by: str = SENTINEL,
        modified_date: str = SENTINEL,
        note: str = SENTINEL,
        previous_stage: PreviousStage = SENTINEL,
        priority_branch: PriorityBranch = SENTINEL,
        source_branch_id: str = SENTINEL,
        source_branch_name: str = SENTINEL,
        stage: MergeRequestStage = SENTINEL,
        strategy: Strategy = SENTINEL,
        **kwargs,
    ):
        """MergeRequest

        :param merge_request_details: merge_request_details
        :type merge_request_details: MergeRequestDetails
        :param created_by: The user who created the merge request., defaults to None
        :type created_by: str, optional
        :param created_date: The date and time the merge request was created., defaults to None
        :type created_date: str, optional
        :param destination_branch_id: The ID of the destination branch., defaults to None
        :type destination_branch_id: str, optional
        :param destination_branch_name: destination_branch_name, defaults to None
        :type destination_branch_name: str, optional
        :param id_: id_, defaults to None
        :type id_: str, optional
        :param inactive_date: inactive_date, defaults to None
        :type inactive_date: str, optional
        :param lock_nonce: lock_nonce, defaults to None
        :type lock_nonce: int, optional
        :param locked_by: locked_by, defaults to None
        :type locked_by: str, optional
        :param locked_date: locked_date, defaults to None
        :type locked_date: str, optional
        :param merge_request_action: merge_request_action, defaults to None
        :type merge_request_action: MergeRequestAction, optional
        :param modified_by: The user who last modified the merge request., defaults to None
        :type modified_by: str, optional
        :param modified_date: The date and time the merge request was last modified., defaults to None
        :type modified_date: str, optional
        :param note: note, defaults to None
        :type note: str, optional
        :param previous_stage: The previous stage of the merge., defaults to None
        :type previous_stage: PreviousStage, optional
        :param priority_branch: The branch which should take priority in an override merge., defaults to None
        :type priority_branch: PriorityBranch, optional
        :param source_branch_id: The ID of the source branch., defaults to None
        :type source_branch_id: str, optional
        :param source_branch_name: source_branch_name, defaults to None
        :type source_branch_name: str, optional
        :param stage: The current stage of the merge., defaults to None
        :type stage: MergeRequestStage, optional
        :param strategy: The merge strategy., defaults to None
        :type strategy: Strategy, optional
        """
        self.merge_request_details = self._define_object(
            merge_request_details, MergeRequestDetails
        )
        if created_by is not SENTINEL:
            self.created_by = created_by
        if created_date is not SENTINEL:
            self.created_date = created_date
        if destination_branch_id is not SENTINEL:
            self.destination_branch_id = destination_branch_id
        if destination_branch_name is not SENTINEL:
            self.destination_branch_name = destination_branch_name
        if id_ is not SENTINEL:
            self.id_ = id_
        if inactive_date is not SENTINEL:
            self.inactive_date = inactive_date
        if lock_nonce is not SENTINEL:
            self.lock_nonce = lock_nonce
        if locked_by is not SENTINEL:
            self.locked_by = locked_by
        if locked_date is not SENTINEL:
            self.locked_date = locked_date
        if merge_request_action is not SENTINEL:
            self.merge_request_action = self._enum_matching(
                merge_request_action, MergeRequestAction.list(), "merge_request_action"
            )
        if modified_by is not SENTINEL:
            self.modified_by = modified_by
        if modified_date is not SENTINEL:
            self.modified_date = modified_date
        if note is not SENTINEL:
            self.note = note
        if previous_stage is not SENTINEL:
            self.previous_stage = self._enum_matching(
                previous_stage, PreviousStage.list(), "previous_stage"
            )
        if priority_branch is not SENTINEL:
            self.priority_branch = self._enum_matching(
                priority_branch, PriorityBranch.list(), "priority_branch"
            )
        if source_branch_id is not SENTINEL:
            self.source_branch_id = source_branch_id
        if source_branch_name is not SENTINEL:
            self.source_branch_name = source_branch_name
        if stage is not SENTINEL:
            self.stage = self._enum_matching(stage, MergeRequestStage.list(), "stage")
        if strategy is not SENTINEL:
            self.strategy = self._enum_matching(strategy, Strategy.list(), "strategy")
        self._kwargs = kwargs
